/* DOSCenterDlg.cpp : implementation file

DOSCenter - a zip file scanner and renamer tool.

 jeff@silent.net - if you're looking to help/improve/take over this project, please contact me.  i have many more ideas.
 
 Similar to ROMCenter in that it can take a bunch of zip files, compare them against a .dat file and suggest to rename the top level (.zip) filename if a match occurrs.
 Better than ROMCenter (in this application) in that it doesn't get tricked by seeing the same file inside multiple zips and thinking they are all the same.
 Eg, gwbasic.exe is inside many early games.  ROMCenter finds the 1st instance of gwbasic.exe in the .dat file and assumes all games are to be renamed as the first .dat instance.
 DOSCenter looks through every entry in the .dat file and tries to find the best match against the target .zip file.
  
 DOSCenter also has other tools to assist in organizing and naming a DOS collection, including renaming files by hand, a zip merge utility, and a built in file viewer.


 we use CMaps for storing each entry from the .dat file.  i am particularly cmap dumb, so my implementation is likely very poor and memory wasting.

stuff to add:


?done? fix next/prev compare buttons, show where data miscompares
inject info from notes page into .dat file?
dcnotice.ini - files contained in here are to be flagged for attention. 
better .dat file configuration system.  method to view .dat file header from main dialog.  maybe an info block at the bottom of the list controls.
better organization of the GUIs.  settings dialog is a mess, some stuff must be set there before you can create a .dat file.
better color organization of left side panel.
.dat file editor - could easily switch to displaying the top level names as "zip files" on the left, and showing the contents of the cmap on the right. - partially implemented now.
show missing files on left side (ie, an incomplete set of zips)
allow alternate (pklite, lz91'ed) files inside the same zip

possible conditions:
file is unscanned = black
file is recognized, missing some files = red
file is recognized, additional files = purple
file is recognized, filename is wrong = brown
file is perfect, contents and name and exact matches = green.
both missing and extra files = blue


inside the zip:
file is unknown = black
file is missing = red
file is ignored = gray
filename mismatch, CRC match, alternate = brown
file is perfect = green

in dat view:
file is black = normal
file is brown = torrentzipped.

*/

#include "stdafx.h"
#include "DOSCenter.h"
#include "DOSCenterDlg.h"
#include "SADirRead.h"
#include "progressDlg.h"
#include ".\doscenterdlg.h"
#include "fileStuff.h"
#include "popupviewerdlg.h"
#include "NewFilenameDlg.h"
#include "registry.h"
#include "SettingsandTools.h"
#include "HexCompareDlg.h"
#include "PopupViewerTxtDlg.h"
#include "HaveMissDlg.h"
#include "dizInfo.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

// minimum size of file to CRC scan.  this helps avoid getting collisions on batch files or other tiny things.
// note that we skip files both from the zip and the .dat which are below this threshold.

//#define NUM_SKIPFILES 8	// files to ignore when scanning, stuff like file_id.diz, gwbasic, and other known repeat offenders
//CString m_ignoreFile[NUM_SKIPFILES]; // global.  populated in OnInitDialog(), and then not used at the moment.


// CAboutDlg dialog used for App About

class CAboutDlg : public CDialog
{
public:
	CAboutDlg();

// Dialog Data
	enum { IDD = IDD_ABOUTBOX };

	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support

// Implementation
protected:
	DECLARE_MESSAGE_MAP()
};

CAboutDlg::CAboutDlg() : CDialog(CAboutDlg::IDD)
{
}

void CAboutDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
}

BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
END_MESSAGE_MAP()


// CDOSCenterDlg dialog



CDOSCenterDlg::CDOSCenterDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CDOSCenterDlg::IDD, pParent)
{
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CDOSCenterDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	DDX_Control(pDX, IDC_LEFTSIDELIST, theApp.m_leftSideList);
	DDX_Control(pDX, IDC_ZIPDETAILSLIST, theApp.m_zipDetailsList);
	DDX_Control(pDX, IDC_LEFTSIDEDATLIST, theApp.m_leftSideDATList);
}

BEGIN_MESSAGE_MAP(CDOSCenterDlg, CDialog)
	ON_WM_SYSCOMMAND()
	ON_WM_PAINT()
	ON_WM_SIZE()
	ON_WM_QUERYDRAGICON()
	//}}AFX_MSG_MAP
	ON_BN_CLICKED(IDC_ZIPFOLDERBROWSEBTN, OnBnClickedZipfolderbrowsebtn)
	ON_NOTIFY(NM_DBLCLK, IDC_LEFTSIDELIST, OnNMDblclkZipFileList)
	ON_NOTIFY(NM_DBLCLK, IDC_ZIPDETAILSLIST, OnNMDblclkZipList)
	ON_NOTIFY(NM_DBLCLK, IDC_LEFTSIDEDATLIST, OnNMDblclkDatFileList)
	ON_NOTIFY(NM_RCLICK, IDC_LEFTSIDELIST, OnNMRclickLeftSideList)
	ON_NOTIFY(NM_RCLICK, IDC_ZIPDETAILSLIST, OnNMRclickRightSideList)
	ON_BN_CLICKED(IDOK, OnBnClickedOk)
	ON_BN_CLICKED(IDC_HIDEMATCHES, OnBnClickedHidematches)
	ON_BN_CLICKED(IDC_HIDEMISSING, OnBnClickedHidemissing)
	ON_BN_CLICKED(IDC_HIDEUNKNOWN, OnBnClickedHideunknown)
	ON_NOTIFY(LVN_KEYDOWN, IDC_ZIPDETAILSLIST, OnLvnKeydownZipdetailslist)
	ON_NOTIFY(LVN_KEYDOWN, IDC_LEFTSIDELIST, OnLvnKeydownLeftsidelist)
	ON_BN_CLICKED(IDC_SETTINGSBTN, OnBnClickedSettingsbtn)
	ON_BN_CLICKED(IDC_APPLYIGNORE, OnBnClickedApplyignore)
	ON_BN_CLICKED(IDC_HIDEALTS, OnBnClickedHidealts)
	//ON_BN_CLICKED(IDC_MISSINGLIST, OnBnClickedMissinglist)
	ON_MESSAGE(WM_DROPFILES,OnDropFiles)
	ON_BN_CLICKED(IDC_DATZIPFLIP, OnBnClickedDatzipflip)
END_MESSAGE_MAP()

// royal PITA for resizing the windows based on the splitter and dialog frame.  
// no other controls seem to work at all for moving their positions, and it flickers like a mofo.
//
BEGIN_EASYSIZE_MAP(CDOSCenterDlg) // ID, left, top, right, bottom
	EASYSIZE(IDC_ZIPDETAILSLIST,IDC_SPLITTER1,IDC_FILENAMETXT,ES_BORDER,IDC_HIDEMATCHES,0)
END_EASYSIZE_MAP

void CDOSCenterDlg::OnSize(UINT nType, int cx, int cy) 
{
    CDialog::OnSize(nType, cx, cy);
    UPDATE_EASYSIZE;
				
	CRect rcZip, rcLeft;	// keep the splitter inside the window
	CWnd* pWndZip;
	CWnd* pWndLeft;
	pWndZip = GetDlgItem(IDC_ZIPDETAILSLIST);
	pWndLeft = GetDlgItem(IDC_LEFTSIDELIST);
	if (pWndZip)
	{
		pWndZip->GetWindowRect(rcZip);
		pWndLeft->GetWindowRect(rcLeft);
		m_wndSplitter1.SetRange(rcLeft.left, rcZip.right-25);
	}

}
LRESULT CDOSCenterDlg::DefWindowProc(UINT message, WPARAM wParam, LPARAM lParam) 
{
	///CRect rect, rect2;

	if (message == WM_NOTIFY)
	{


				




		if (wParam == IDC_SPLITTER1) // moving the splitter?
		{	
			
				//CWnd* pWndSp;
				
				//CRect rcSp;
				
				//pWndSp = GetDlgItem(IDC_SPLITTER1);
				//pWndSp->GetWindowRect(rcSp);
				
				
				
				
				
				
				SPC_NMHDR* pHdr = (SPC_NMHDR*) lParam;
				DoResize1(pHdr->delta);
		}
//		else if (wParam == IDC_SPLITTER2)
//		{
//			SPC_NMHDR* pHdr = (SPC_NMHDR*) lParam;
//			DoResize2(pHdr->delta);
//		}
	}
	
	return CDialog::DefWindowProc(message, wParam, lParam);
}

void CDOSCenterDlg::DoResize1(int delta)
{
	CSplitterControl::ChangeWidth(&theApp.m_leftSideList, delta);
	CSplitterControl::ChangeWidth(&theApp.m_leftSideDATList, delta);
	CSplitterControl::ChangeWidth(&theApp.m_zipDetailsList, -delta, CW_RIGHTALIGN);
//	CSplitterControl::ChangeWidth(&m_txtContent, -delta, CW_RIGHTALIGN);
//	CSplitterControl::ChangeWidth(&m_wndSplitter2, -delta, CW_RIGHTALIGN);
	Invalidate();
	UpdateWindow();
}

// CDOSCenterDlg message handlers


void CDOSCenterDlg::OnCancel() 
{
	CString txt;
	theApp.m_tmpWorkingFolder.TrimRight("\\DOSCenter");
	CRegistry regMyReg( CREG_CREATE );  // create registry key if it doesn't exist.
	if ( regMyReg.Open("Software\\DOSCenter",HKEY_CURRENT_USER) ) 
		{
			regMyReg["workingFolder"] = theApp.m_tmpWorkingFolder;
			regMyReg["collectionPath"] = theApp.m_collectionPath;
			regMyReg["defaultMovePath"] = theApp.m_defaultMovePath;
			regMyReg["DOSBoxPath"] = theApp.m_dosboxPath;

			// save user prefs
			if ( theApp.m_autoLoadDat ) 
				regMyReg["autoLoadDAT"] = "1";
			else
				regMyReg["autoLoadDAT"] = "0";


//			if ( theApp.m_ScanCRCFilename ) 
//				regMyReg["CRCScanOnly"] = "1";
//			else
//				regMyReg["CRCScanOnly"] = "0";



			if ( ((CButton*)GetDlgItem(IDC_RECURSIZESCAN))->GetCheck() == 1)
                regMyReg["recursiveZipScan"] = "1";
			else
                regMyReg["recursiveZipScan"] = "0";

			if (theApp.m_detailedReport == true)
                regMyReg["detailedReport"] = "1";
			else
                regMyReg["detailedReport"] = "0";

			txt.Format("%d", theApp.m_minScoreForAutoRename);
			regMyReg["autoRenameMinScore"] = txt;

			regMyReg["FXP login"] = theApp.m_mySitesDat;
			regMyReg["FXP dlpath"] = theApp.m_fxpDlPath;

			regMyReg.Close();
		}
			
//	if (theApp.m_fileData->fileCount != 0)
//			delete[] theApp.m_fileData;	// delete existing cmap and crap under it.
	CDialog::OnCancel();

}


BOOL CDOSCenterDlg::OnInitDialog()
{
	CString tmp;
	CDialog::OnInitDialog();
	CFileStuff files;
	CSettingsandTools settings;
	// Add "About..." menu item to system menu.

	// IDM_ABOUTBOX must be in the system command range.
	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT(IDM_ABOUTBOX < 0xF000);

	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if (pSysMenu != NULL)
	{
		CString strAboutMenu;
		strAboutMenu.LoadString(IDS_ABOUTBOX);
		if (!strAboutMenu.IsEmpty())
		{
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
		}
	}

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon

//	SetRegistryKey(_T("DOSCenter"));
	
	theApp.m_DATfileLoaded = false;
	theApp.m_reloadIgnore = false;


	// dig out some registry stuff
	CRegistry regMyReg( NULL );  // No special flags

	if ( regMyReg.Open("Software\\DOSCenter",HKEY_CURRENT_USER) ) 
	{
		// get the data
		m_SourcePath = regMyReg["zipFolders"];
		theApp.m_DATPath = regMyReg["datFolders"];
		theApp.m_collectionPath = regMyReg["collectionPath"];
		theApp.m_tmpWorkingFolder = regMyReg["workingFolder"];
		theApp.m_defaultMovePath = regMyReg["defaultMovePath"];
		theApp.m_dosboxPath = regMyReg["DOSBoxPath"];
		theApp.m_mySitesDat= regMyReg["FXP login"];
		if (theApp.m_mySitesDat.GetLength() == 0)
			theApp.m_mySitesDat = "n/a";
		theApp.m_fxpDlPath = regMyReg["FXP dlpath"];
		if (theApp.m_fxpDlPath.GetLength()==0)
			theApp.m_fxpDlPath = "c:\\";
		tmp = regMyReg["autoLoadDAT"];
		theApp.m_autoLoadDat = 0;
		if (tmp == "1") 
			theApp.m_autoLoadDat = 1;

	//	tmp = regMyReg["CRCScanOnly"];
	//	theApp.m_ScanCRCFilename = true;
	//	if (tmp == "0") 
	//		theApp.m_ScanCRCFilename = false;




		tmp = regMyReg["autoRenameMinScore"];
		if (tmp.GetLength() == 0)
			tmp = "100";
		sscanf(tmp, "%d", &theApp.m_minScoreForAutoRename);

		tmp = regMyReg["recursiveZipScan"];
		((CButton*)GetDlgItem(IDC_RECURSIZESCAN))->SetCheck(0);
		if (tmp == "1") 
			((CButton*)GetDlgItem(IDC_RECURSIZESCAN))->SetCheck(1);

		theApp.m_detailedReport = false;

        if (regMyReg["detailedReport"] == "1")
			theApp.m_detailedReport = true;
		

		// Close the open key
		regMyReg.Close();

	}


	if (theApp.m_dosboxPath.GetLength() == 0)
		theApp.m_dosboxPath = "c:\\";
	if (theApp.m_defaultMovePath.GetLength() == 0)
		theApp.m_defaultMovePath = "c:\\";
	if (theApp.m_tmpWorkingFolder.GetLength() == 0)
		theApp.m_tmpWorkingFolder = "c:\\temp";
	theApp.m_tmpWorkingFolder +="\\DOSCenter";



	((CButton*)GetDlgItem(IDC_ZIPFOLDERTXT))->SetWindowText("Zip folder: "+m_SourcePath);

	// clean up any leftover unzips
	CreateDirectory(_T(theApp.m_tmpWorkingFolder), NULL); // just in case
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder))
		AfxMessageBox("Warning, unable to clean up previous DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);

	CreateDirectory(_T(theApp.m_tmpWorkingFolder), NULL); // create it again, so it's clean.


	// Restore Window-Position

	WINDOWPLACEMENT *lwp;
	UINT nl;

	if(AfxGetApp()->GetProfileBinary("DOSCenterMAIN", "WP", (LPBYTE*)&lwp, &nl))
	{
		lwp->showCmd=SW_SHOWNORMAL; // <<-my magic line of code Smile
		SetWindowPlacement(lwp);
	}

	// draw a splitter
	CWnd* pWnd;
	CRect rc;

	pWnd = GetDlgItem(IDC_SPLITTER1);
	pWnd->GetWindowRect(rc);
	ScreenToClient(rc);
	m_wndSplitter1.Create(WS_CHILD | WS_VISIBLE, rc, this, IDC_SPLITTER1);
	m_wndSplitter1.SetRange(450, 1000, -1);

	// move the splitter into restored position.  all we care about is the left position.
	if(AfxGetApp()->GetProfileBinary("DOSCenterSPLIT", "SPLIT", (LPBYTE*)&lwp, &nl))
	{
		m_wndSplitter1.SetWindowPlacement(lwp);
		
		DoResize1(lwp->rcNormalPosition.left - 480);	// this is a total guess.  i'm sure if you change the splitter "setrange" this needs to be updated too.
	}

	// create our columns in each window pane
	// color column is invisible to the user, but controls the text color displayed
	theApp.m_leftSideList.SetExtendedStyle( LVS_EX_FULLROWSELECT );
	theApp.m_leftSideList.SetHeadings( _T("Color,0; Filename,150; New Filename,200; Score,40; ==,30; xx,30; ??,30;") );
	theApp.m_leftSideList.LoadColumnInfo();

	theApp.m_zipDetailsList.SetExtendedStyle( LVS_EX_FULLROWSELECT );
	theApp.m_zipDetailsList.SetHeadings( _T("Color,0; name,80; type,40; size,70; date,70; crc,70") );
	theApp.m_zipDetailsList.LoadColumnInfo();

	theApp.m_leftSideDATList.SetExtendedStyle( LVS_EX_FULLROWSELECT );
	theApp.m_leftSideDATList.SetHeadings( _T("Color,0; name,150; count,40") );
	theApp.m_leftSideDATList.LoadColumnInfo();
	theApp.m_leftSideDATList.ShowWindow(0);
	m_datview = false;
	theApp.m_datParsed = false;


	_COLUMNWIDTHS *columns;
	if(AfxGetApp()->GetProfileBinary("DOSCenterCOLS", "COLS", (LPBYTE*)&columns, &nl))
	{
		theApp.m_zipDetailsList.SetColumnWidth(COLORCOL, columns->Rcolor);
		theApp.m_zipDetailsList.SetColumnWidth(1, columns->Rname);	
		theApp.m_zipDetailsList.SetColumnWidth(2, columns->Rtype);	
		theApp.m_zipDetailsList.SetColumnWidth(3, columns->Rsize);	
		theApp.m_zipDetailsList.SetColumnWidth(4, columns->Rdate);	
		theApp.m_zipDetailsList.SetColumnWidth(5, columns->Rcrc);	

		theApp.m_leftSideList.SetColumnWidth(COLORCOL, columns->Lcolor);
		theApp.m_leftSideList.SetColumnWidth(FILENAMECOL, columns->Lfilename);
		theApp.m_leftSideList.SetColumnWidth(NEWFILENAMECOL, columns->Lnewfilename);
		if (columns->Lscore > 1000)
			columns->Lscore = 40;
		theApp.m_leftSideList.SetColumnWidth(SCORECOL, columns->Lscore);		

		if (columns->Lmatched > 1000)
			columns->Lmatched = 40;
		theApp.m_leftSideList.SetColumnWidth(MATCHCOL, columns->Lmatched);

		if (columns->Lmissing > 1000)
			columns->Lmissing = 40;
		theApp.m_leftSideList.SetColumnWidth(MISSCOL, columns->Lmissing);

		if (columns->Lunknown > 1000)
			columns->Lunknown = 40;
		theApp.m_leftSideList.SetColumnWidth(UNKCOL, columns->Lunknown);
		
		// dat view
		if (columns->LViewName > 1000)
			columns->LViewName = 150;
		theApp.m_leftSideDATList.SetColumnWidth(1, columns->LViewName);
	}

	if (m_SourcePath.GetLength() > 0)
		updateZipList();

	populateIgnoreList();
	theApp.m_ignoreOn = true;
	((CButton*)GetDlgItem(IDC_APPLYIGNORE))->SetCheck(theApp.m_ignoreOn);

	// allocate a pile o' memory for the .dat file
	theApp.m_ROMDATEntryName.InitHashTable(323579,true);
	theApp.m_ROMDATEntryCRC.InitHashTable(323579,true);
	theApp.m_datfileCount = 0;

	if (theApp.m_autoLoadDat)
		settings.parseDATFile();

	DragAcceptFiles(TRUE); // To Accept Dropped file Set this TRUE


	return TRUE;  // return TRUE  unless you set the focus to a control
}




BOOL CDOSCenterDlg::DestroyWindow() 
{
    _COLUMNWIDTHS columns;
	WINDOWPLACEMENT wp;
    GetWindowPlacement(&wp);
	AfxGetApp()->WriteProfileBinary("DOSCenterMAIN", "WP", (LPBYTE)&wp, sizeof(wp));

	// save the splitter position
	m_wndSplitter1.GetWindowPlacement(&wp);
	AfxGetApp()->WriteProfileBinary("DOSCenterSPLIT", "SPLIT", (LPBYTE)&wp, sizeof(wp));
	
	// save the column widths
	columns.Rcolor = theApp.m_zipDetailsList.GetColumnWidth(COLORCOL);
	columns.Rname = theApp.m_zipDetailsList.GetColumnWidth(1);	
	columns.Rtype = theApp.m_zipDetailsList.GetColumnWidth(2);	
	columns.Rsize = theApp.m_zipDetailsList.GetColumnWidth(3);	
	columns.Rdate = theApp.m_zipDetailsList.GetColumnWidth(4);	
	columns.Rcrc = theApp.m_zipDetailsList.GetColumnWidth(5);	

	columns.Lcolor = theApp.m_leftSideList.GetColumnWidth(COLORCOL);
	columns.Lfilename = theApp.m_leftSideList.GetColumnWidth(FILENAMECOL);
	columns.Lnewfilename = theApp.m_leftSideList.GetColumnWidth(NEWFILENAMECOL);
	columns.Lscore = theApp.m_leftSideList.GetColumnWidth(SCORECOL);
	columns.Lmatched = theApp.m_leftSideList.GetColumnWidth(MATCHCOL);
	columns.Lmissing = theApp.m_leftSideList.GetColumnWidth(MISSCOL);
	columns.Lunknown = theApp.m_leftSideList.GetColumnWidth(UNKCOL);
	columns.LViewName = theApp.m_leftSideDATList.GetColumnWidth(1);	//dat view name column

	AfxGetApp()->WriteProfileBinary("DOSCenterCOLS", "COLS", (LPBYTE)&columns, sizeof(columns));    
	return CDialog::DestroyWindow();
}

void CDOSCenterDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
	{
		CAboutDlg dlgAbout;
		dlgAbout.DoModal();
	}
	else
	{
		CDialog::OnSysCommand(nID, lParam);
	}
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CDOSCenterDlg::OnPaint() 
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this function to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CDOSCenterDlg::OnQueryDragIcon()
{
	return static_cast<HCURSOR>(m_hIcon);
}

// get the source zip files we want to interrogate
void CDOSCenterDlg::OnBnClickedZipfolderbrowsebtn()
{
	CFileStuff fileStuff;
	// open a "browse to folder" dialog
	if (fileStuff.UserBrowseFolder(m_SourcePath, "Where's your ZIP collection?") != TRUE)
		return;
	if (m_SourcePath.Right(1) != "\\")
		m_SourcePath+="\\";

	updateZipList();
	if ( ((CButton*)GetDlgItem(IDC_AUTOSCAN))->GetCheck() )
		scanAllFiles();

	CRegistry regMyReg( CREG_CREATE );  // create registry key if it doesn't exist.
	if ( regMyReg.Open("Software\\DOSCenter",HKEY_CURRENT_USER) ) 
		{
			// Now set the new values
			regMyReg["zipFolders"] = m_SourcePath;
			regMyReg.Close();
		}
	CString txt;
	txt.Format("Zip folder:"+m_SourcePath+",%d files",m_zipCount);
	((CButton*)GetDlgItem(IDC_ZIPFOLDERTXT))->SetWindowText(txt);
}

//refresh the left side pane with all the zip files we're looking at.
void CDOSCenterDlg::updateZipList()
{
	CString filename;
	theApp.m_leftSideList.DeleteAllItems();
	m_zipCount = 0;
	bool recurse;
	recurse = ( ((CButton*)GetDlgItem(IDC_RECURSIZESCAN))->GetCheck() == 1);

	// now we have the path+filename we want to work with.
	// scan all the files in this selected folder.
	m_zipDir.ClearDirs();
	m_zipDir.ClearFiles();
	// look in the user folder
	m_zipDir.GetDirs(m_SourcePath, recurse);


   ///////////////////////////////////////////////////
   // get all files in the dirs we found above
   m_zipDir.GetFiles("*.zip");

   // sort them by name, ascending
   m_zipDir.SortFiles(CSADirRead::eSortAlpha, false);
   CSADirRead::SAFileVector &files = m_zipDir.Files();
   m_zipFiles = files.begin();

   // list all files on the left side
   while ( m_zipFiles != files.end())
   {
		filename = (*m_zipFiles).m_sName;
		filename.Replace(m_SourcePath,"");
		
		theApp.m_leftSideList.AddItem(COLOR_BLACK, filename, "", "", "", "", "");	// column 0 is color, zipfilename, new filename, score, match, missing, unknown
		m_zipFiles++;	// next file please
		m_zipCount++;
   }
}


// user has 2x clicked on a file on the left side - show all the files inside the zip
// if we've got a .dat file loaded, check to see if there are any hits and display CRC's that are matching in green.
//inside the zip:
//file is perfect = dark green
//file is unknown to the entire .dat file = black
//file is missing = red
//file is ignored = gray
//filename mismatch, CRC match = light green
//filename match, CRC mismatch = brown
//file found elsewhere in .dat, but not in this entry = purple
//? files in this entry but also in other .dat entries? = green/brown+purple?
void CDOSCenterDlg::OnNMDblclkZipFileList(NMHDR *pNMHDR, LRESULT *pResult)
{
	UZ_FileInfo info;
	int	m_nFileCount;
	unsigned int scanned=-1;	
	CString filename, ext, size, crc, date, scanSuggest, tmp;
	WORD dosDate;
	WORD dosTime;
	CTime time;
	CString color;
	CString tmpext;
	CString zipDir;
	ZIPdata tempZIPdata;		// temporary storage for the zip file (from the .dat) the data came from
	ROMdata tempROMdata;		// temporary storage for the ROM file(s) in this zip
	ROMdata lookupROMdata;		// more temporary storage for the lookup

	bool showOnly=false;
	int	datPos;

	theApp.m_zipIsFoldered = false;


	int nIndex;
	CString zipfilename;

	// no selection?  abort
	nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
	if (nIndex == -1)
		return;
	
	// get the name of the zip file that the scanner is suggesting we use.
	zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);	// phsyical filename
	scanSuggest = theApp.m_leftSideList.GetItemText(nIndex, NEWFILENAMECOL);		// .dat file zip filename
	
	// unless of course there are no new filename suggestions, so we need the physical filename
	if (scanSuggest == "perfect!")
		scanSuggest = theApp.m_leftSideList.GetItemText(nIndex, FILENAMECOL);

	if (scanSuggest == "no good matches")	// save a little time by not looking this up
		scanSuggest="";

	// yank out any folder information to get to the raw filename
	if (scanSuggest.Find('\\') != -1) 
		scanSuggest = scanSuggest.Right(scanSuggest.GetLength() - (scanSuggest.ReverseFind('\\')) -1 );

	// if there is no scanned filename, there is no need to compare CRCs, just list the zip contents
	if (scanSuggest.GetLength()==0)
		showOnly=true;
	else
		datPos = getDatPtr(scanSuggest);	// figure out where in the .dat we want to look

	// delete the current list of files if it's there.
	theApp.m_zipDetailsList.DeleteAllItems();


	zipDir = findRootZipFolder(m_SourcePath+zipfilename);
	if (zipDir.GetLength() > 0)
	{
//		m_uz.GotoNextFile();
		theApp.m_zipDetailsList.AddItem(COLOR_PBROWN,"Warning, all files inside folder", zipDir, "", "", "");	// add a note
		theApp.m_zipIsFoldered = true;
		m_buriedZipFolder = zipDir;
	}


	// grab the zip and start displaying each file inside.
	if (m_uz.OpenZip(m_SourcePath+zipfilename) == false)
	{
		AfxMessageBox("There's something goofy with this file. - can't open it!", MB_ICONWARNING, 0);
		return;
	}
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();

	
	// set the GUI text
	tmp.Format(" - %d file(s)",m_nFileCount);
	tmp=zipfilename+tmp;
	((CButton*)GetDlgItem(IDC_FILENAMETXT))->SetWindowText(tmp);


	// we now have a zip file with some roms in it
	// and a .dat file entry that has some roms in it.
	// we need to go through each of both and mark off the CRC, filename and timestamp matches.
	// then we print a list of all the files in the zip along with the extra stuff in the .dat
	//
	// there are some tricky bits here.
	// could have duplicate filename in the zip with the same CRC, but with different filenames (or in a folder)
	// could have a filename match, but the CRC is different (common)




	// for each rom in the actual zip we've just peeked at...
	// load them into a temporary map so we can check 'em against the .dat
	for (int i=0; i<m_nFileCount; i++)
	{
		// store the roms in a scratch cmap
		filename = info.szFileName;
		
		theApp.m_tmpzipList[i].fileName = filename;
		theApp.m_tmpzipList[i].crc = info.dwCRC;
		theApp.m_tmpzipList[i].size = info.dwUncompressedSize;
		theApp.m_tmpzipList[i].status = 0;
		theApp.m_tmpzipList[i].date = info.dwDosDate;
		m_uz.GotoNextFile();
		m_uz.GetFileInfo(info);
	}
	m_uz.CloseZip();


	if (!showOnly)
	{
		checkDatvsZip(datPos, m_nFileCount, false);	// compare .dat entry to rom files
		theApp.m_tmpzipList[0].ptr2zipFileArray = datPos;
	}
	

	// now display each ROM
	for (int i=0; i<m_nFileCount; i++)
	{
		color = COLOR_BLACK;	// default unknown color		
		filename = theApp.m_tmpzipList[i].fileName;

		size.Format("%d",theApp.m_tmpzipList[i].size);	
		crc.Format("%08x", theApp.m_tmpzipList[i].crc);
		dosDate = (WORD)(theApp.m_tmpzipList[i].date >> 16);
		dosTime = (WORD)theApp.m_tmpzipList[i].date & 0xffff;
		CTime time(dosDate, dosTime);
		date =time.Format( "%Y/%m/%d %H:%M:%S" );
		ext = extractExtension(filename);

		int q = theApp.m_tmpzipList[i].status;
		if ( (theApp.m_tmpzipList[i].status == 0) && (!showOnly))// unknown file (for this dat) but it may exist elsewhere.  quick look it up.
		{
			if (theApp.m_ROMDATEntryCRC.Lookup(crc, lookupROMdata))
			{// CRC hit?
				theApp.m_datZipListit = theApp.m_datZipList.find(lookupROMdata.ptr2zipFileArray);
				CString zipName = theApp.m_datZipListit->second.filename;	// 2nd element is the 2nd thing stored in this map. weird stuff.
				theApp.m_tmpzipList[i].newFileName = zipName;
				theApp.m_tmpzipList[i].status = STATUS_ROM_ELSEWHERE;
				color = COLOR_PURPLE;
			}
		}
		else
		// add this file into the right side window list
		// separate out the extension from the filename
		if ((theApp.m_tmpzipList[i].status & STATUS_ROM_PERFECT_MATCH) == STATUS_ROM_PERFECT_MATCH)
			color = COLOR_GREEN;
		else // CRC match, filename mismatch
        if ((theApp.m_tmpzipList[i].status & STATUS_ROM_CRC_MATCH) == STATUS_ROM_CRC_MATCH)
			color = COLOR_LGREEN;
		else // CRC mismatch, filename match
		if ((theApp.m_tmpzipList[i].status & STATUS_ROM_FILENAME_MATCH) == STATUS_ROM_FILENAME_MATCH)
			color = COLOR_BROWN;
		
		// check if this file is in our ignore list.  if so, color it gray.
		// but only do that if we haven't already matched it.
		if (theApp.m_tmpzipList[i].status == STATUS_ROM_IGNORED)
			color = COLOR_GRAY;

		// check if the user wants to hide these files
		if ( ( (color == COLOR_GREEN) || (color == COLOR_LGREEN)) && ((CButton*)GetDlgItem(IDC_HIDEMATCHES))->GetCheck() )	// does the user want to see these items?
			color = COLOR_HIDE;

		if ((color == COLOR_BLACK) && ((CButton*)GetDlgItem(IDC_HIDEUNKNOWN))->GetCheck() )	// does the user want to see these items?
			color = COLOR_HIDE;
		
		if (color != COLOR_HIDE)
			theApp.m_zipDetailsList.AddItem(color,filename, ext, size, date, crc);	// add this entry to the list
	}
	
	if ( (showOnly) || ((CButton*)GetDlgItem(IDC_HIDEMISSING))->GetCheck() ) // only if the user wants this stuff
		goto exit;

	////////////////
	// display missing files - anything in the .dat that we have not discovered in the physical zip
	////////////////
	
	
	for (int j=0; j<theApp.m_datZipList[datPos].fileCount; j++)
	{
		if ( (theApp.m_datZipList[datPos].ROMsMap[j].status != 0) && (theApp.m_datZipList[datPos].ROMsMap[j].status != STATUS_ROM_IGNORED) )
			continue;

		color = COLOR_RED;
		filename = theApp.m_datZipList[datPos].ROMsMap[j].name;
		size.Format("%d", theApp.m_datZipList[datPos].ROMsMap[j].size);	
		crc.Format("%08x", theApp.m_datZipList[datPos].ROMsMap[j].crc);
		dosDate = (WORD)(theApp.m_datZipList[datPos].ROMsMap[j].date >> 16);
		dosTime = (WORD)theApp.m_datZipList[datPos].ROMsMap[j].date & 0xffff;
		CTime time(dosDate, dosTime);
		date =time.Format( "%Y/%m/%d %H:%M:%S" );
		ext = extractExtension(filename);

		// hang on pardner.  if this file is in our ignore list, it's not really missing. 
		//if (skipafile(filename, ext, theApp.m_datZipList[datPos].ROMsMap[j].crc, theApp.m_datZipList[datPos].ROMsMap[j].size))
		
		if (theApp.m_datZipList[datPos].ROMsMap[j].status == STATUS_ROM_IGNORED)
			color = COLOR_RED_IGNORED;
		// if this file was ignored in teh dat file AND found in the zip, skip displaying it altogether.
//		if (theApp.m_datZipList[datPos].ROMsMap[j].status == (STATUS_ROM_IGNORED+STATUS_ROM_FILENAME_MATCH) )
//			color = "0x987654";
		if (!filename.IsEmpty())
			theApp.m_zipDetailsList.AddItem(color,filename, ext, size, date, crc);	// add this entry to the list
	}

	// clean up our .dat entry
	for (int j=0; j<theApp.m_datZipList[datPos].fileCount; j++)
		theApp.m_datZipList[datPos].ROMsMap[j].status = 0;

exit:


/*



	int i=0;
	while(1)	// gather all the info for each file in this zip and display it on the right hand window
	{

		filename = info.szFileName;
		filename = filename.Right(filename.GetLength() - zipDir.GetLength());	// trim off any leading directory info
		// huck each "rom" from the zip into a cmap so we can peek at it later
		theApp.m_tmpzipList[i].fileName = filename;
		theApp.m_tmpzipList[i].crc = info.dwCRC;
		theApp.m_tmpzipList[i].size = info.dwUncompressedSize;
		theApp.m_tmpzipList[i].status = 0; // default not found yet
		CString fnamBakup = filename;
		ext = extractExtension(filename);

		size.Format("%d",info.dwUncompressedSize);	
		crc.Format("%08x", info.dwCRC);
		dosDate = (WORD)(info.dwDosDate >> 16);
		dosTime = (WORD)info.dwDosDate & 0xffff;
		DosDateTimeToFileTime(dosDate, dosTime, &dateTime);
		FileTimeToSystemTime(&dateTime, &sysTime);
		date.Format("%d/%d/%d %d:%02d", sysTime.wYear,sysTime.wMonth,sysTime.wDay,sysTime.wHour,sysTime.wMinute);

		// display all the files in this zip in color
		color = COLOR_BLACK; //default color, unscanned.



		// figure out which color to make this file
		if (scanSuggest.GetLength()>0) // only color code a file if we've scanned and compared it to something
		{
			// create a key out of the rom's CRC
			tmp=crc;
			tmp.MakeLower();
			ROMFilenameKey = tmp;
			// see if this rom filename exists in our collection
			if (theApp.m_ROMDATEntryCRC.Lookup(ROMFilenameKey, tempROMdata))	// found a match.  we have to check for collisions though.
			{
				color = COLOR_BLACK;			// assume we have no idea what this file matches
				while (1)
				{
					CString localtmp=ROMFilenameKey;	// just in case we need to look this one up multiple times
					// first check to make sure there aren't multiple files in the same zip with the same CRC.  yep, it happens.
					while (tempROMdata.collision == true)
					{
						
						CString tmpROMDatFilename = tempROMdata.fileName;
						if (tmpROMDatFilename.MakeLower() == fnamBakup.MakeLower()) // did we find it?
							break;
						
						theApp.makeNewKey(localtmp);
						theApp.m_ROMDATEntryCRC.Lookup(localtmp, tempROMdata);


					}


					// continue searching until we have a match of this name to the zip file that we've suggested.
					theApp.m_datZipListit = theApp.m_datZipList.find(tempROMdata.ptr2zipFileArray); // is this ROM file located in the ZIP file from the .dat that we're suggesting?
					CString tmpROMDatFilename = tempROMdata.fileName;
					if (scanSuggest == theApp.m_datZipListit->second.filename)	// 2nd element is the 2nd thing stored in this map.
					{
						zipPosPtr = tempROMdata.ptr2zipFileArray; // save a pointer to this zip file from the dat so we can look it up later.
						color = COLOR_GREEN;		// finally! we have a hit
						theApp.m_tmpzipList[i].status = STATUS_ROM_FOUND;	// leave ourselves a flag that we have noted this file
						theApp.m_tmpzipList[i].ptr2zipFileArray = zipPosPtr;

						
						if (tmpROMDatFilename.MakeLower() != fnamBakup.MakeLower() ) // make sure the name is exact before calling it perfect.
						{
							color = COLOR_YELLOW;
							theApp.m_tmpzipList[i].status = STATUS_ROM_NAMEWEIRD;
							theApp.m_tmpzipList[i].newFileName = tempROMdata.fileName;
							
						}
						if ( ((CButton*)GetDlgItem(IDC_HIDEMATCHES))->GetCheck() )	// does the user want to see these items?
							color = COLOR_HIDE;
						break;	// we are done.
					}	
					// are there multiple files that have this crc?  Look 'em up.
					if (tempROMdata.collision == true)
					{
						// make a new file and get the new data
						if (tmp.GetLength() > 10)
							int g=0;

						tmp = ROMFilenameKey;
						theApp.makeNewKey(tmp);
						ROMFilenameKey = tmp;
						if (!theApp.m_ROMDATEntryCRC.Lookup(ROMFilenameKey, tempROMdata))
							continue;	// keep checking
					}
					else // no more collisions, this happens when a crc exists, but not in our zip that we just opened.  These would technically be unknown, but it's cool we can catch em here.
					{
						color = COLOR_PURPLE;	// zip filename placement mismatch
						tmpZipPosPtr = tempROMdata.ptr2zipFileArray; // save a pointer to this zip file from the dat so we can look it up later.
						theApp.m_tmpzipList[i].ptr2zipFileArray = tmpZipPosPtr;
						theApp.m_tmpzipList[i].status = STATUS_ROM_ELSEWHERE;	// leave ourselves a flag that we have noted this file, but it's goofy
						break;
					}
				} // collision check
			} // hit


			// check the file against any ignore files in the database.  color those gray if there's a match.
			if (( skipafile(filename, ext, info.dwCRC, info.dwUncompressedSize) == true) && (color != COLOR_HIDE) )
			{
				theApp.m_tmpzipList[i].status = STATUS_ROM_IGNORED;
				color = COLOR_GRAY;
			}
		}  // scanned


		// if the user doesn't want to see unknown (black color) files, hide them here.
		if ( (color == COLOR_BLACK) && ((CButton*)GetDlgItem(IDC_HIDEUNKNOWN))->GetCheck() )	// does the user want to see these items?
			color = COLOR_HIDE;



		// color set, finally add this file to the list 
		if (color != COLOR_HIDE)
			theApp.m_zipDetailsList.AddItem(color,filename, ext, size, date, crc);	// everything else


		if (m_uz.GotoNextFile() == false)
			break;
		m_uz.GetFileInfo(info);
		i++;

	}
*/

/*

	////////////////
	// display missing files
	////////////////
	// now display any files that were missing from the zip file in red.
	if ( (!((CButton*)GetDlgItem(IDC_HIDEMISSING))->GetCheck()) && (scanSuggest.GetLength() != 0) ) // only if the user wants this stuff
	{
		CString x,y;
		for (int i=0; i<theApp.m_datZipList[zipPosPtr].fileCount; i++) // for each rom file in this zip's .dat entry
		{
			if ((theApp.m_datZipList[zipPosPtr].ROMsMap[i].status & DATENTRY_STATUS_IGNORE) == DATENTRY_STATUS_IGNORE)
				continue;
			x = theApp.m_datZipList[zipPosPtr].ROMsMap[i].name;
			x.MakeLower();
			color = COLOR_RED;		// assume the file is missing
			date = "--missing--";   // user flag for a missng file in date column
			bool found=false;		// assume this one is missing
			y="fd";
			int j=0;
			while (y.GetLength() > 0)
		
			//for (int j=0; j<m_nFileCount; j++)	// for each file in the zip - seems this number is inaccurate when there is a file in the ignore list.
            {
				int foundStatus=theApp.m_tmpzipList[j].status;
				y = theApp.m_tmpzipList[j].fileName;
				//CString x = theApp.m_datZipList[zipPosPtr].ROMsMap[i].name;
				//x.MakeLower();
				y.MakeLower();
				// check the filename from the dat against each filename in the zip
				// is this filename a match?  if so, we have a CRC mismatch, but filename is ok.
				if (x == y)
					{
						if (foundStatus == STATUS_ROM_FOUND)
						{
							found = true;
							break;
						}
						//if (foundStatus != 0)	// we only want files here that we didn't locate above to speed up this process
						//{
						//	found = true;
					//		continue;						// we don't care - we've already found this one
					//	}
						color = COLOR_BROWN;	  // filename match, but we know the CRC doesn't, otherwise it'd be green above.
						date = "--Diff. CRC--";   // user flag for a bad CRC

						found = false;			  // force this one to display when we exit the loop
					}
		//		else // filename mismatch.  we may have already covered this one.
		//			if (foundStatus == STATUS_ROM_NAMEWEIRD)	
		//			{					
		//				found=true;
		//				break;
		//			}
					j++;
			} // for each file in the zip we just opened.

			// do we want to display this one?
				if (!found) 
				{
					filename = theApp.m_datZipList[zipPosPtr].ROMsMap[i].name;
	
					ext = extractExtension(filename);

					size.Format("%d", theApp.m_datZipList[zipPosPtr].ROMsMap[i].size);	
					crc.Format("%08x", theApp.m_datZipList[zipPosPtr].ROMsMap[i].crc);
				//dosDate = (WORD)(info.dwDosDate >> 16);
				//dosTime = (WORD)info.dwDosDate & 0xffff;
				//DosDateTimeToFileTime(dosDate, dosTime, &dateTime);
				//FileTimeToSystemTime(&dateTime, &sysTime);
				//date.Format("%d/%d/%d %d:%02d", sysTime.wYear,sysTime.wMonth,sysTime.wDay,sysTime.wHour,sysTime.wMinute);
					theApp.m_zipDetailsList.AddItem(color, filename, ext, size, date, crc);	// everything else
				}			

		} 


*/



/*
		for (int i=0; i<theApp.m_datZipList[zipPosPtr].fileCount; i++)	// for all the files in this zip dat entry...
		{
			// get the filename




		}
		CString q = theApp.m_datZipList[zipPosPtr].ROMsMap[0].name;
/*
		if (scanSuggest.GetLength()>0) // only do this if we've scanned and compared it to something from the .dat
			{
				// we need to parse through the entire dat file collection and find ROMs that point back to the zip we're suggesting.  
				POSITION pos = theApp.m_ROMDATEntry.GetStartPosition();
				CString whatever;
                while (pos !=NULL)
				{
					theApp.m_ROMDATEntry.GetNextAssoc( pos,whatever, tempROMdata);
					if (tempROMdata.ptr2zipFileArray == zipPosPtr) // is this a ROM file that came from our suggested zip?
					{
						theApp.m_datZipListit = theApp.m_datZipList.find(tempROMdata.ptr2zipFileArray); // is this ROM file located in the ZIP file from the .dat that we're suggesting?
						if (scanSuggest == theApp.m_datZipListit->second.filename)

				}
				


				theApp.m_datZipListit = theApp.m_datZipList.find(zipPosPtr); // point to the zip
					if (scanSuggest == theApp.m_datZipListit->second.filename)	// 2nd element is the 2nd thing stored in this map.
					
				m_copyfileData[0].it = m_copyfileData[0].mymap.begin();
				while( m_copyfileData[0].it != m_copyfileData[0].mymap.end() ) 
				{
					if ( (m_copyfileData[0].it->second.found != true) && (m_copyfileData[0].it->second.name != "") )
					{
						filename = m_copyfileData[0].it->second.name; 
						ext = filename.Right(filename.GetLength() - filename.ReverseFind('.'));
						filename = filename.Left(filename.GetLength() - ext.GetLength());
						if (filename == "")
						{
							filename = ext;
							ext = "";
						}
						ext.TrimLeft(".");
						size.Format("%d",m_copyfileData[0].it->second.size);
						crc.Format("%08x",m_copyfileData[0].it->second.crc);
						if (skipafile(filename, ext, m_copyfileData[0].it->second.crc, m_copyfileData[0].it->second.size) == false)
							theApp.m_zipDetailsList.AddItem(COLOR_RED,filename, ext, size, "-missing-", crc);
						if (m_copyfileData[0].it->second.alternate == true)
							theApp.m_zipDetailsList.AddItem(COLOR_PURPLE,filename, ext, size, "-alternate-", crc);
					}
				m_copyfileData[0].it++;
				}
			}
			*/
//	} // if view enabled
	// save the selected zip filename, in case the user wants to do anything else with it.
	theApp.m_currentlyTaggedZipFile = zipfilename;



	// huck the copy of the file data
//	delete[] m_copyfileData;

}

// input: "c:\mypath\mypath2\mypath3\myzipfilename.zip"
// outpt: "myzipfilename.zip"
CString CDOSCenterDlg::extractFilenameWOPath(CString filename)
{
	return filename.Right(filename.GetLength() - (filename.ReverseFind('\\')) -1 );
}

CString CDOSCenterDlg::extractExtension(CString &filename)
{
	CString ext = filename.Right(filename.GetLength() - filename.ReverseFind('.'));
	filename = filename.Left(filename.GetLength() - ext.GetLength());
	if (filename == "")
	{
		filename = ext;
		ext = "";
	}
	ext.TrimLeft(".");
	return ext;
}


// user has 2x clicked on a file inside a zip - popup a view dialog and display the contents
void CDOSCenterDlg::OnNMDblclkZipList(NMHDR *pNMHDR, LRESULT *pResult)
{
	hexViewFile();
}

void CDOSCenterDlg::hexViewFile()
{
	FILE* inFile;
	CString fileData;
	CFileStuff file;
	CString filename, txt, ascii;
	UZ_FileInfo info;
	CProgressDlg progDlg;
	bool showAscii = true;

	int nIndex;
	nIndex = theApp.m_zipDetailsList.GetNextItem(-1, LVNI_SELECTED);
	filename = theApp.m_zipDetailsList.GetItemText(nIndex,1);
	filename +="."+theApp.m_zipDetailsList.GetItemText(nIndex,2);	// extension
	
	filename.TrimRight(".");
	// dump the folder and just dig the file out.
	// if there are duplicate files in different folders, we will always get the 1st one.

	txt = filename.Right(filename.GetLength()-filename.ReverseFind('\\')-1);
	if (txt.GetLength() > 0)
		filename= txt;


	if (theApp.m_zipDetailsList.GetItemText(nIndex,COLORCOL) == COLOR_RED)	// don't allow us to 2x click a missing file.
		return;


	m_uz.OpenZip(m_SourcePath+theApp.m_currentlyTaggedZipFile);
	m_uz.GotoFile(filename,1); // ignore path
	
	
	m_uz.GetFileInfo(info);
	if (!m_uz.UnzipFile(theApp.m_tmpWorkingFolder, 1))	// ignore file path
	{
		AfxMessageBox("Ack.  An unzip error occurred. This zip file might be old and compressed with Shrink based compression. \
		  \r\nYou should try to refresh/recompress this zip file with winRAR or similar and try again." , MB_ICONERROR, 0);
		m_uz.CloseZip();
		return;
	}

	// make sure the file is not set to read-only.
	SetFileAttributes( theApp.m_tmpWorkingFolder+"\\"+filename,  GetFileAttributes(theApp.m_tmpWorkingFolder+"\\"+filename) & ~FILE_ATTRIBUTE_READONLY);
	m_uz.CloseZip();
	unsigned int size = info.dwUncompressedSize + (16 - (info.dwUncompressedSize & 0xf));
	// now open the file and display it in the popup viewer
	inFile = fopen(theApp.m_tmpWorkingFolder+"\\"+filename,"rb");
	char* buffer = new char[size];
	memset(buffer,0,size);


	if (inFile != NULL)
		fread(buffer,info.dwUncompressedSize,1 ,inFile);

	// close input file
	if (inFile != NULL)
			fclose(inFile);	


	if (info.dwUncompressedSize > 1024 * 1024)
	{	
		progDlg.Init(PROG_MODE_TIMER, 1000, "Creating display...");
	}


	// check for all ASCII characters.  popup the correct viewer depending on data.
	for (unsigned int i=0; i<info.dwUncompressedSize; i++)
		if ((unsigned char)buffer[i] < 9)	// ascii
		{
			showAscii = false;
			break;
		}

	if (showAscii)
	{
		CPopupViewerTxtDlg dlg;

		fileData = buffer;

		dlg.m_viewerTxt = fileData;
		dlg.m_fileNameViewer = filename;
		dlg.DoModal();
	}
	else	// hex view - it would be super sweet to be able to exit the strings view in the hex view and come back to the hex viewer.  Since the hex viewer doesn't actually have
			// the data in it, we can't really parse the data again inside thehex viewer to launch the strings view.  we'd need to have the buffer created globally for that, which would
			// be doable...  or could do the strings stuff anyway in anticipation that the user is going to click the button, then pass the data into the hex viewer to be launched from there.
	{
		CPopupViewerDlg dlg;

		// convert data into nice hex display with offset and ascii bytes.
		for (unsigned int q=0; q<size; q++)
		{
			if ((q & 0xf) == 0x00)	// offset
			{
				txt.Format("%08x", q);
				fileData+=txt+"  ";
			}
			txt.Format("%02X", (unsigned char)buffer[q]);
			fileData+=txt+" ";

			if ((unsigned char)buffer[q] < 31)	// ascii
				ascii+=".";
			else 
				ascii+=buffer[q];

			if ((q & 0xf) == 0xf) // add ascii and CRLF
			{
				fileData+="  "+ascii+"\r\n";	
				ascii="";
			}
			if ( ((q & 0xf) !=0xf) && ((q & 7) == 7)) fileData+="- ";
		}
	
		dlg.m_viewerTxt = fileData;
		dlg.m_fileNameViewer = filename;
		dlg.DoModal();

		//
		// display the strings viewer from within the hex viewer.  neato.
		// 
		if (dlg.m_bStrings == true)
		{
			CPopupViewerTxtDlg dlg;
			fileData = "";
			txt = "";
			int count = 0;
				
			for (unsigned int q=0; q<size; q++)
				{
					if ( ((unsigned char)buffer[q] > 31) && ((unsigned char)buffer[q] < 127) )	// ascii
					{
						txt+=buffer[q];
						count++;
					}
					else
						if (count > 4)	// add string to our output
						{
							fileData+=txt+"\r\n";
							count = 0;
							txt = "";
						}
						else	// just start over
						{
							count = 0;
							txt = "";
						}


				}
	
			dlg.m_viewerTxt = fileData;
			dlg.m_fileNameViewer = filename;
			dlg.DoModal();
		} // end of strings view

	} // hex display

	if (info.dwUncompressedSize > 1024 * 1024)
	{	
		progDlg.DestroyWindow();
	}

	delete []buffer;
}


// user has right clicked inside the zip file list window
// display a pop up window with available options (rename, scan, merge, etc)
void CDOSCenterDlg::OnNMRclickLeftSideList(NMHDR *pNMHDR, LRESULT *pResult)
{
#define MENU_MERGE 4
#define MENU_SCAN 3
#define MENU_FIXZIP 8

	*pResult = 0;
	CNewFilenameDlg dlg;
	int nIndex=-1;
	int lastDeleted=0;
	CString source,dest;
	CString fromClipboard;
	CString tmp;
	int count=0;



	CPoint point;                                            
     ::GetCursorPos(&point); //where is the mouse?


	CMenu menu; //lets display our context menu :) 

    DWORD dwSelectionMade;                                       
    VERIFY(menu.LoadMenu(IDR_MENU1) );  

	CMenu *pmenuPopup = menu.GetSubMenu(0);


	 // no selection?  no menu
	nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
	if (nIndex == -1)
		return;

	// gray merged selection if only 1 file is selected.
	while (1) 
		{
			count++;
			nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
			if (nIndex == -1)
				break;
		}
	if ( (count < 2) || (count > 100) )
	 pmenuPopup->EnableMenuItem(MENU_MERGE, MF_GRAYED+MF_BYPOSITION);	// kill the merge option if only 1 selected file


	nIndex = -1;	// reset index

	if (theApp.m_DATfileLoaded == false)
	{
		pmenuPopup->EnableMenuItem(MENU_SCAN, MF_GRAYED+MF_BYPOSITION);	// kill the scan option if no dat file has been loaded
		pmenuPopup->EnableMenuItem(MENU_FIXZIP, MF_GRAYED+MF_BYPOSITION);	// kill the fix option if no dat file has been loaded
	}
	ASSERT(pmenuPopup != NULL);                                       

	 
	dwSelectionMade = pmenuPopup->TrackPopupMenu( (TPM_LEFTALIGN|TPM_LEFTBUTTON|TPM_NONOTIFY|TPM_RETURNCMD), point.x, point.y, this);                                


	 if (dwSelectionMade == ID__RENAMEFROMCLIPBOARD)
	 {
		char * buffer = NULL;
		//open the clipboard to get the new filename
		if ( OpenClipboard() ) 
		{
			HANDLE hData = GetClipboardData( CF_TEXT );
			char * buffer = (char*)GlobalLock( hData );
			fromClipboard = buffer;
			GlobalUnlock( hData );
			CloseClipboard();
		}
		if ( (fromClipboard.Right(4) != ".zip") && (fromClipboard.Right(4) != ".ZIP") )
			fromClipboard+=".zip";
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
		dlg.m_txt = fromClipboard;
		// popup an edit box
		dlg.DoModal();
		if (dlg.m_ok == 1)
		{
			dest = dlg.m_txt;
			dest.Replace("\t"," ");
		// go do the rename
			if (!MoveFile(m_SourcePath+source, m_SourcePath+dest))
				AfxMessageBox("Error renaming file! "+m_SourcePath+source, MB_ICONEXCLAMATION, 0);
			else
			{
			//updateZipList(); // can't do this-if we've scanned a lot of files, we lose all that data!
				theApp.m_leftSideList.SetItemText(nIndex, FILENAMECOL, dest);
				theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,"");
			}
		}
	}

	 if (dwSelectionMade == ID_RENAME_RENAMEBYHAND)
		 renameZipFileWithPopUpDialog();

	 
	 // automagic rename of "suggested" title in the 2nd column.
	if (dwSelectionMade == ID_RENAME_RENAMESELECTED)
	{
		CString sScore;
		CString subPath;
		int score;
		int renamed=0;

		while (1) 
			{
				nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;
				sScore = theApp.m_leftSideList.GetItemText(nIndex,SCORECOL);
				sscanf(sScore, "%d",&score);
				if ( (score >= theApp.m_minScoreForAutoRename) && 
					(theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL).GetLength() > 0) && 
					(theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "perfect!" ) && 
					(theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "no good matches") )
				{
					source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
					subPath = source.Left(source.ReverseFind('\\'));
					if (subPath.GetLength() != 0)
						subPath+="\\";
					dest = theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL);				
					
						if (!MoveFile(m_SourcePath+source, m_SourcePath+subPath+dest))
							AfxMessageBox("Error renaming file! "+m_SourcePath+source, MB_ICONEXCLAMATION, 0);
					else
						{
							theApp.m_leftSideList.SetItemText(nIndex,FILENAMECOL,subPath+dest);
							theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,"");
							renamed++;
						}
				}
			}
		if (renamed ==0)
			AfxMessageBox("Warning, no files were renamed.  Check the \"auto rename score\" value in settings and tools.", MB_ICONINFORMATION, 0);
	}

	 if (dwSelectionMade == ID__DELETE)
	 {
		// count number of items in list-popup verify message.
		count=0;
		while (1) 
			{
				nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;
				count++;
			}
		tmp.Format("Delete %d file(s)?", count);
		int choice = AfxMessageBox(tmp, MB_ICONWARNING | MB_YESNO, 0);
			if ( choice == IDNO )
				return;

		nIndex=-1;	// ok then, delete away!
		
		while (1) 
		{
			nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
			if (nIndex == -1)
				break;
			else
			{
				source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
				remove(m_SourcePath+source);
				theApp.m_leftSideList.DeleteItem (nIndex);
			}
		}
	 }

	if (dwSelectionMade == ID__SCAN)
	{
		scanSelectedZips();
	}

	if (dwSelectionMade == ID__MERGE)
	{
		mergeZipFiles();
	}

	if (dwSelectionMade == ID__RENAME_FORGET)
	{
		while (1) // find the selection
			{
				nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;
				theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,"no good matches");
				theApp.m_leftSideList.SetItemText(nIndex,COLORCOL,COLOR_BLACK);
			}
	}

	if (dwSelectionMade == ID_MOVE_HOME)
	{
		moveSelectedFiles(theApp.m_collectionPath);
	}
	if (dwSelectionMade == ID_MOVE_BROWSE)
	{
		CFileStuff fileStuff;
		// open a "browse to folder" dialog
		if (fileStuff.UserBrowseFolder(theApp.m_defaultMovePath, "Move file(s) to...") != TRUE)
			return;
		
		tmp = theApp.m_defaultMovePath; 
		if (tmp.Right(1) != "\\")
			tmp+="\\";
		moveSelectedFiles(tmp);
	}

	if (dwSelectionMade == ID__UNZIPTOTEMP)
	{
		
		nIndex=-1;
		nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
		source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
		unzipAFile(m_SourcePath+source, theApp.m_dosboxPath);

	}

	if (dwSelectionMade == ID__YEARSCAN)
		doYearScan();

	if (dwSelectionMade == ID__REFRESH)
		updateZipList();

	if (dwSelectionMade == ID__FIXZIPFILE)
		fixAZip();

	 pmenuPopup->DestroyMenu(); 
}

// scan a zip, if it is missing any files, attempt to locate an update zip.  Take file from update pack and add it to this zip
// if zip has additional files, delete them
void CDOSCenterDlg::fixAZip()
{
	// scan the zip
	CProgressDlg progDlg;
	int nIndex=-1;
	CString tmp, color;
	int matches;
	int missing, unknown;
	int score;
	int flags=0;
	CString targetZip;
	CFileStuff files;

	// browse for folder with update packs
	//fixme - dig m_updatePackSourcePath out of the registry
	if (m_updatePackSourcePath.IsEmpty())
	{
		if (files.UserBrowseFolder(m_updatePackSourcePath, "Where's your update packs?") != TRUE)
		return;
	}


	progDlg.Init(PROG_MODE_TIMER, 1000, "Scanning file...");

	while (1) 
	{
		
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		
		targetZip = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);

		progDlg.UpdateText("Scanning file...", theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL));
		score = scanAZipFile(targetZip, matches, missing, unknown, flags);
		//theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,m_topTen[0].filename); 
	
		if (score > 30)		// lower range of what we can fix.  totally arbitrary and untested.
		{
			// fix this zip
			progDlg.UpdateText("Fixing file...", theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL));
			bool results = fixazip(targetZip, m_topTen[0].zipPos);
			if (results)
			{
				// rename the file if needed
				if (m_topTen[0].filename != targetZip)
				{
					MoveFile(m_SourcePath+"\\"+targetZip, m_SourcePath+"\\"+m_topTen[0].filename);
					theApp.m_leftSideList.SetItemText(nIndex,FILENAMECOL,m_topTen[0].filename);	// update screen
				}
				// rescan it again
				targetZip = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
				//progDlg.UpdateText("Scanning file...", theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL));
				scanThisZip(nIndex, &progDlg);
			}
			else
			{	// we have failed to repair this zip.  let the user know.  we should make a log of what was done.


			}
		

		}
	} // all selected items

	progDlg.DestroyWindow();
}

// add a file into a target zip.
// note: there are a lot of duplicate routines here- this should be optimized.
// ie, pass in an array of files to add to a zip- this would work with the drag-n-drop feature too.
bool CDOSCenterDlg::addAFileToAZip(CString targetZip, CString addThisfile)
{
	//char	szDroppedFile[MAX_PATH];
	//HDROP	hDrop ;
	int nFiles=0;
	CString csString;
	int	nIndex=-1;
	CString dest;

	int	m_nFileCount;
	UZ_FileInfo info;
	ZIPMERGE* zipMerge;
	zipMerge = new _ZIPMERGE[1];	
	//CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
	CString tmp, ext;
	CFileStuff files; 


	// do we have multiple files selected on the left?  can't handle that either.
	// ok, we could do multiple zips on the left, but let's not for now.
	while (1)
	{
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		nFiles++;		
	}

	if (nFiles !=1)
		return 0;

	// get destination filename - make it just a variation of the filename we've selected
	//nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
	//zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
	targetZipName = targetZip; //zipfilename;
	// trim off any folder
	targetZipName = extractFilenameWOPath(targetZipName);
	targetZipName.Insert(0,"WIP");

	// create a temporary folder
	CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);
	if (!m_uz.Unzip(m_SourcePath+targetZip, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))	// unzip old file
		{
			AfxMessageBox("Error unzipping file! "+targetZip, MB_ICONEXCLAMATION, 0);
			m_uz.CloseZip();
			// delete temporary work space
			if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
				AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
			delete[] zipMerge;
			return 0;
		}
	m_uz.CloseZip();


	// put all files inside this zip into the array
	m_uz.OpenZip(m_SourcePath+targetZip);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();
	for (int i=0; i<m_nFileCount; i++)	// for each file in the zip...
		{
			// add filename or new filename into array
			filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+info.szFileName;
			zipMerge[0].mymap[filename].name = filename;
			m_uz.GotoNextFile();
			m_uz.GetFileInfo(info);
        }
	m_uz.CloseZip();

	// now add the extra files dragged in.
	//hDrop = (HDROP)wParam;
	//UpdateData();

	//nFiles = DragQueryFile(hDrop,		// Struture Identifier
	//			  -1,			// -1 to Drop more than one file
	//			  szDroppedFile,// Droped File Name
	//			  MAX_PATH);	// Max char

	m_nFileCount++;
	nFiles=1;

	// for each file, add the path into our zip array.
	for(int i=0;i<nFiles;i++)
		{
			//DragQueryFile(hDrop,i,szDroppedFile,MAX_PATH);
			//filename = szDroppedFile;
			zipMerge[0].mymap[addThisfile].name = addThisfile;
		}





	// zip it all back up.
//	progDlg.UpdateText("Creating new zip:"+targetZipName);
	
	m_zip.OpenZip(m_SourcePath+"\\"+targetZipName, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"); // create a fresh zip file

	zipMerge[0].it = zipMerge[0].mymap.begin();
			while( zipMerge[0].it != zipMerge[0].mymap.end() ) 
			{
				filename = zipMerge[0].it->first;
				m_zip.AddFileToZip(filename, true);
				zipMerge[0].it++;
			}

	m_zip.CloseZip();



	// delete the original file, move the new one back in.
//	progDlg.UpdateText("Cleaning up...");
	
	remove(m_SourcePath+targetZip);
	MoveFile(m_SourcePath+targetZipName, m_SourcePath+targetZip);

	// delete temporary work space
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);


	OnNMDblclkZipFileList(0, 0);
	delete[] zipMerge;
//	progDlg.DestroyWindow();
	return 0;
}


// search for a supplied file in an update pack
bool CDOSCenterDlg::extractFileFromUpdatePack(CString filename, CString scrc)
{
	unsigned int crc;
	UZ_FileInfo info;
	sscanf(scrc,"%x",&crc);	
	m_uz.OpenZip("c:\\TDCR6updatePack.zip"); //fixme - this needs to be variabled

	// make sure the correct file+CRC exist in the update pack
	if (!m_uz.GotoFile(filename,1))
		return 0;
	
	m_uz.GetFileInfo(info);
	if (info.dwCRC != crc)	// exact file not found?
		return 0;
	
	if (!m_uz.UnzipFile(theApp.m_tmpWorkingFolder, 1))	// ignore file path
	{
		AfxMessageBox("Ack.  An unzip error occurred. This zip file might be old and compressed with Shrink based compression. \
		\r\nYou should try to refresh/recompress this zip file with winRAR or similar and try again." , MB_ICONERROR, 0);
		m_uz.CloseZip();
		return 0;
	}
	// make sure the file is not set to read-only.
	SetFileAttributes( theApp.m_tmpWorkingFolder+"\\"+filename,  GetFileAttributes(theApp.m_tmpWorkingFolder+"\\"+filename) & ~FILE_ATTRIBUTE_READONLY);
	m_uz.CloseZip();

	return 1;
}


void CDOSCenterDlg::renameZipFileWithPopUpDialog()
 {
		int nIndex=-1;
		CString source, dest, subPath;
		CNewFilenameDlg dlg;

		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
		subPath = source.Left(source.ReverseFind('\\'));
		if (subPath.GetLength() != 0)
			subPath+="\\";
		dlg.m_txt = source;
		if ( (theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "") && (theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "no good matches") 
		  && (theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "perfect!")  )
			dlg.m_txt = subPath+theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL);
			
		dlg.DoModal();
		// popup an edit box
		if (dlg.m_ok == 1)
		{
			dest = dlg.m_txt;
			dest.Replace("\t"," ");
			dest.Trim();



			if (!MoveFile(m_SourcePath+source, m_SourcePath+dest))
				AfxMessageBox("Error renaming file! "+m_SourcePath+source, MB_ICONEXCLAMATION, 0);
			else
			{
		//	updateZipList();  // can't do this-if we've scanned a lot of files, we lose all that data!
				theApp.m_leftSideList.SetItemText(nIndex,FILENAMECOL,dest);
				theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,"");
			}
		}

	// refresh zip listing, if open
	OnNMDblclkZipFileList(NULL, NULL);

}





// huck a zipped file's contents to the work folder
void CDOSCenterDlg::unzipAFile(CString zipFilename, CString destination)
{
	int nIndex=-1;
	int	m_nFileCount;
	UZ_FileInfo info;

	m_uz.OpenZip(zipFilename);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	if ( (info.dwVersion !=0) && (info.dwVersion < 0x10) )
	{
		AfxMessageBox("Zip file is compressed with 1.x version of zip.  This zlib can't handle those files.  You can convert zips in bulk with winRAR.  Sorry.\n"+zipFilename, MB_ICONEXCLAMATION, 0);
		m_uz.CloseZip();
		return;
	}
	m_nFileCount = m_uz.GetFileCount();
	if (!m_uz.Unzip(zipFilename, destination))
		AfxMessageBox("Error unzipping file! "+zipFilename, MB_ICONEXCLAMATION, 0);
//	else
		//AfxMessageBox("Unzipped %d files.",m_nFileCount, MB_ICONINFORMATION, 0);
	m_uz.CloseZip();
}


// move any files highlighted in the left side list to tgtPath
void CDOSCenterDlg::moveSelectedFiles(CString tgtPath)
{
	int nIndex;
	CString zipfilename;
	CString source;
	nIndex=-1;
	while (1) 
	{
		nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		else
		{
			source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
			zipfilename = source;
			if (zipfilename.Find('\\') != -1) 
				zipfilename = zipfilename.Right(zipfilename.GetLength() - (zipfilename.ReverseFind('\\')) -1 );

			if (!MoveFile(m_SourcePath+source, tgtPath+zipfilename))
			{
				AfxMessageBox("Error moving file!? "+m_SourcePath+source, MB_ICONEXCLAMATION, 0);
				return;
			}
			theApp.m_leftSideList.DeleteItem (nIndex);
		}
	}
}

///////////////////////////////////////////////////////////////////////////////////////////
// ZIP MERGE
// take multiple zip files, check for CRC collisions, unzip and then rezip.
// TODO: add an option to delete source files when finished?
// TODO: add logging capabilities so that we know we've done the job properly.
bool CDOSCenterDlg::mergeZipFiles()
{
//	FILE* logFile;	//todo - i wanted to have a log file of all the input files+paths so that it can be verified against the final zip file
	CString logData;

	int nIndex=-1;
	int	m_nFileCount;
	UZ_FileInfo info;
	ZIPMERGE* zipMerge;
	zipMerge = new _ZIPMERGE[1];	
	CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
	CString tmp, ext;
	CFileStuff files; 

	CProgressDlg progDlg;

	// get destination filename - make it just a variation of the 1st filename in the selected pool
	nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
	targetZipName = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
	ext = targetZipName.Right(targetZipName.GetLength() - targetZipName.ReverseFind('.'));
	
	logData = "\r\nMerging zip files:\r\n"+targetZipName;
	
	while (1)  // get the last filename too
	{
		tmp = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
		logData+="\r\n"+tmp;
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
	}
	logData+="\r\n";

	targetZipName = targetZipName.Left(targetZipName.GetLength() - ext.GetLength());
	targetZipName +="_"+tmp.Left(tmp.GetLength() - ext.GetLength());
	targetZipName +="_merged.zip";

	logData+="Destination file: "+targetZipName+"\r\n";

	// maybe popup a new filename dialog, with options to delete original files.
	
	nIndex = -1; // reset
	progDlg.Init(PROG_MODE_TIMER, 1000, "Checking for CRC/Filename collisions...");
	// scan all selected files and make sure there are no collisions (same filename+diferent crc)
	// list collisions.
	while (1) 
	{
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		else
		{	// put all files inside this zip into the array
			zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
			m_uz.OpenZip(m_SourcePath+zipfilename);
			m_uz.GotoFirstFile();
			m_uz.GetFileInfo(info);
			m_nFileCount = m_uz.GetFileCount();

			for (int i=0; i<m_nFileCount; i++)	// gather all the info for each file in this zip and display it on the right hand window
			{
				filename = info.szFileName;
				if (zipMerge[0].mymap[filename].name.GetLength() != 0)
				{
					// collision - check crc
					if ( (zipMerge[0].mymap[filename].crc != info.dwCRC) || (zipMerge[0].mymap[filename].name != filename) )
					{
						tmp = "Filename/crc collision in zip files! "+filename+"\r\nContinue?";
						int choice = AfxMessageBox(tmp, MB_ICONWARNING | MB_YESNO, 0);
						if ( choice == IDNO )
						{
							progDlg.DestroyWindow();
							m_uz.CloseZip();
							delete[] zipMerge;
							return false;
						}
					}
				}
				else
				{
					zipMerge[0].mymap[filename].name = filename;
					zipMerge[0].mymap[filename].crc = info.dwCRC;
				}
				m_uz.GotoNextFile();
				m_uz.GetFileInfo(info);
            }
	
		}
		m_uz.CloseZip();
	} //while selected

	progDlg.UpdateText("Unzipping files...");
	// create a temporary folder
	CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);

	// ok, no collisions detected.  unzip each to a temp folder
	while (1) 
	{
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		else
		{	
			zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
			if (!m_uz.Unzip(m_SourcePath+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))
				{
					logData+="\r\n**Error unzipping file:"+zipfilename;
					AfxMessageBox("Error unzipping file! "+zipfilename, MB_ICONEXCLAMATION, 0);
					m_uz.CloseZip();
					progDlg.UpdateText("Cleaning up...");
					// delete temporary work space
					if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
						AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
					progDlg.DestroyWindow();
					delete[] zipMerge;
					return false;
				}

		}

		m_uz.CloseZip();
	} //while selected


	progDlg.UpdateText("Creating new zip:"+targetZipName);
	m_zip.OpenZip(m_SourcePath+"\\"+targetZipName, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"); // create a fresh zip file

	zipMerge[0].it = zipMerge[0].mymap.begin();
			while( zipMerge[0].it != zipMerge[0].mymap.end() ) 
			{
				filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+zipMerge[0].it->first;
				m_zip.AddFileToZip(filename);
				zipMerge[0].it++;
			}

	m_zip.CloseZip();

	progDlg.UpdateText("Cleaning up...");
	// delete temporary work space
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);

	theApp.m_leftSideList.AddItem(COLOR_BLACK, targetZipName, "", "", "", "", "");	// column 0 is color, zipfilename, new filename, score, match, missing, unknown
	m_zipFiles++;	// next file please
	m_zipCount++;

	delete[] zipMerge;
	progDlg.DestroyWindow();
	return true;
}


/////////////////////////////////////////////////////////////////////////////////////////
// ZIP SCANNING/SCORING
// top level file scanning/scoring routine
//file is unscanned = black
//file is recognized, missing some files = red
//file is recognized, additional files = purple
//file is recognized, filename is wrong = brown
//file is perfect, contents and name and exact matches = green.
//matched file in database is torrentzipped, all colors will be slightly off
//
// this routine scans the zip and then updates the screen with the results+score info
// input: index# of file in zip list to scan

void CDOSCenterDlg::scanThisZip(int nIndex, CProgressDlg* progDlg)
{
	CString tmp, color;
	int matches;
	int missing, unknown;
	int score;
	int flags=0;
	//CProgressDlg progDlg;
	if (progDlg != NULL)
		progDlg->UpdateText("Scanning files...", theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL));

	// scan it, get the results
	score = scanAZipFile(theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL), matches, missing, unknown, flags);
	tmp.Format("%d",score);
	theApp.m_leftSideList.SetItemText(nIndex,SCORECOL, tmp);
	tmp.Format("%d",(int)matches);	
	theApp.m_leftSideList.SetItemText(nIndex,MATCHCOL, tmp);
	tmp.Format("%d", missing);
	theApp.m_leftSideList.SetItemText(nIndex,MISSCOL, tmp);
	tmp.Format("%d", unknown);
	theApp.m_leftSideList.SetItemText(nIndex,UNKCOL, tmp);
				

	// any kind of match with the database?  Add the suggested name.
	if (score > 10) //matches > 0.0)
	{
		theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,m_topTen[0].filename);
	
		// all files good, just top level filename is wrong, color is brown
		if ( (missing == 0) && (unknown == 0) && ( score < 100) && ( theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL) != theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) ) )
			color = COLOR_YELLOW; 

		if ( (missing >0) && (unknown == 0) ) // missing some files, but no unknown files
			color = COLOR_RED; 

		if ( (missing ==0) && (unknown >0 ) ) // missing no files, additional files in the zip
			color = COLOR_PURPLE; 
	
		if ( (missing >0) && (unknown >0 ) ) // missing files, and additional files in the zip  totally fubared.  
			color = COLOR_BLUE; 
		
		// get rid of path in filename
		CString tFilename;
		tFilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
		if (tFilename.Find('\\') != -1) 
			tFilename = tFilename.Right(tFilename.GetLength() - (tFilename.ReverseFind('\\')) -1 );

		if ( (missing == 0) && (unknown == 0) && (score == 100) )
		{
			if ( tFilename == theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL))
			{
				theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,"perfect!");
				color = COLOR_GREEN; //theApp.m_leftSideList.SetItemText(nIndex,COLORCOL,COLOR_GREEN);
			}
			else
				color = COLOR_BROWN;
		}

		// if the file in our collection is torrentzipped (we hate those)
		// change the color slightly to let the user know our in-database file could be updated/replaced.
		// get the name of the zip file that the scanner is suggesting we use.
		CString zipFilename = m_topTen[0].filename;	// dat filename
		// scan through the cmap to find this particular entry - fixme - could the iterator be passed in the topTen[0] array?
		theApp.m_datZipListit = theApp.m_datZipList.begin();
		while (theApp.m_datZipListit != theApp.m_datZipList.end())
			{
				if (zipFilename == theApp.m_datZipListit->second.filename)
					break;
				theApp.m_datZipListit++;
			}

		if ((theApp.m_datZipListit->second.status & TZIPPED) == TZIPPED)
		{
			DWORD icolor;
			sscanf(color, "%x", &icolor); 
			icolor |=COLOR_TZIPPED;
			color.Format("0x%x",icolor);
				
		}


	}
	else // no matches at all (score less than 10)
	{
		theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,"no good matches");
		color = COLOR_BLACK;
	}

	theApp.m_leftSideList.SetItemText(nIndex,COLORCOL,color);
	//progDlg.DestroyWindow();
}



// scan multiple zips (anything highlighted)
void CDOSCenterDlg::scanSelectedZips()
{
	CProgressDlg progDlg;
	progDlg.Init(PROG_MODE_TIMER, 1000, "Scanning files, hang on...");

	int nIndex=-1;
	nIndex=-1;
	while (1) 
	{
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		else
			scanThisZip(nIndex, &progDlg);
	} // all selected items
	
	progDlg.DestroyWindow();
}

// compares all CRCs in a given zip file against the .dat file.
// input: path+filename of zip to check
// output: topTen list populated with best candidates for this zip
/*
	scanning - compare the contents of a zip file against CRCs in the .dat file.

	We scan based on CRCs. When a .dat file is loaded, we populate a CMAP of CRCs, which point back to the .dat entry they belong to.
	
	All we want to do here is find the .dat file entry that has the most CRCs from this zip pointing to it.
	
	1) CRC Collisions are ignored. (same file exists in 2 .dat entries, like a soundcard driver)
	2) we keep a small list (10 entries) where files in the zip are pointing to entries in the .dat.  Typically we will find only 1 entry.

	Once the main .dat entry is located, we then take a closer examination of that .dat entry against the .zip, comments below.
*/

int CDOSCenterDlg::scanAZipFile(CString sourceFile, int &matches, int &missing, int &unknown, int &flags)
{
	UZ_FileInfo info;
	int	nFileCount;
	int matchCount=0;
	float datTotal=0.0;
	double onepointoh = 1.0;
	CString sScore;
	CString filename, scrc, ext;
	CString zipDir;
	CString tmp;
	int misses=0;
	//int skipped=0;
	m_zipIgnored=0;
	m_datIgnored=0;
	float score=0.0;
	float datscore =0.0;
	float zipscore = 0.0;
	bool results;
	bool knownGood = false;
	matches = 0;
	missing = 0;
	unknown = 0;
	int datIndex;
	m_exactMatches=0;
	m_zipCRCmatches=0;
//	ZIPdata tempZIPdata;

	m_uz.OpenZip(m_SourcePath+sourceFile);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	nFileCount = m_uz.GetFileCount();
	m_scannedZipFileCount = nFileCount;
	
	m_topTenIdx = 0;	// flush out the topten
	for (int i=0; i<TOPARRAYSIZE; i++)
	{
		m_topTen[i].filename = "";
		m_topTen[i].score=0.0;
		m_topTen[i].zipPos = -1;
		m_topTen[i].dupes =0;
		m_topTen[i].perfects=0;
		m_topTen[i].crcMatch=0;
	}


	// are all the files inside this zip in a subfolder?  strip the subfolder name out since it screws with all of our name matches.
	// all of our .dat file entries should be in the root folder
	zipDir = info.szFileName;
	if (zipDir.Right(1) == '\\')
	{
	
		for (int i=0; i<nFileCount; i++)
		{
			m_uz.GotoNextFile();
			m_uz.GetFileInfo(info);
			tmp = info.szFileName;
			if (tmp.Left(zipDir.GetLength()) == zipDir)
				continue;
			else
			{
				zipDir="";
				break;
			}
		} // for
	}
	else
		zipDir="";


	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);


	for (int i=0; i<nFileCount; i++)	// for each file in the zip...
	{
		
		// store the roms in a scratch cmap that we will look at later
		filename = info.szFileName;		// get filename and CRC
		
		theApp.m_tmpzipList[i].fileName = filename;
		theApp.m_tmpzipList[i].crc = info.dwCRC;
		theApp.m_tmpzipList[i].size = info.dwUncompressedSize;
		theApp.m_tmpzipList[i].status = 0;
		theApp.m_tmpzipList[i].date = info.dwDosDate;
		
		filename.MakeLower();
		filename = filename.Right(filename.GetLength() - zipDir.GetLength());
		ext = extractExtension(filename);
/*
old method
		// is this file in our ignore list?	
		// remember that the .dat file doesn't have any files from our skip list.
		if (skipafile(filename, ext, info.dwCRC, info.dwUncompressedSize) == true)
			filename="";

		if ( filename.GetLength() > 0 )
		{
			if (ext.GetLength() > 0)
				filename+="."+ext;
			results = scanCRCs(info.dwCRC, filename);	// any CRC matches?
		}
		else 
		{
			skipped++;
			m_scannedZipFileCount--;
		}
*/

		if (ext.GetLength() > 0)
			filename+="."+ext;

		if (info.dwCRC != 0)	// skip scanning if CRC=0
		{
            results = scanCRCs(info.dwCRC, filename);	// any CRC matches?
//			if (!results) // not found? this may be on our skip list
//			{
//				extractExtension(filename);
//				if (skipafile(filename, ext, info.dwCRC, info.dwUncompressedSize) == true)
//				{
//					m_datIgnored++;
//					m_zipIgnored++;
//				}
//			}
		}

		m_uz.GotoNextFile();
		m_uz.GetFileInfo(info);
	}
	m_uz.CloseZip();


	// we have now checked all the CRCs of the roms in the zip.  our topTen list should have the the .dat entry that this file matches (if any)




	// if we have multiple entries in our top ten, lets first find the best by the number of perfect matches
	// this should put topTen[0] the closest candidate to the zip we just scanned.
	if (m_topTenIdx > 0)
		sortTopTen();

	// if we have scanned 'em all, but no perfects are present, we can do a deep scan where we check every .dat entry against this zip
	// + user selection
//	if ( (m_topTen[0].perfects ==0) && 1)
//		deepScan(sourceFile);



	datIndex = m_topTen[0].zipPos;
	if (datIndex != -1) // absolutely no matches?
		checkDatvsZip(datIndex, nFileCount, true);	// go compare the given dat entry against the zip array (already populated)


	// save the selected zip filename, in case the user wants to do anything else with it.
	theApp.m_currentlyTaggedZipFile = sourceFile;

	// ok, we have checked each file in the phsyical zip against the .dat database.
	// We know the following data:
    // # of exact rom matches (crc+filename) in this zip vs. the .dat file (m_exactMatches)
	// # of rom name matches, crc mismatches, again from the entire .dat file (m_zipNameMatches)
	// # of crc matches, but filename mismatches (m_zipCRCmatches)
	// # of files in the .dat for each entry of the best matches found (m_topTen[0].datCount)
	// # of unknown files (unknown from the *entire* .dat file) (m_nFileCount - (m_exactMatches + m_zipCRCmatches))
	// # of files in the zip we just scanned	(m_nFileCount)


// sspectre wants the following:
// 1. If both sides have different files (i.e. file have "extra" entries and .dat have "missing" entries), do nothing new.
// 2. If file have extra, and .dat haven't missing entries, score file as 100+%.
// 3. If file haven't extra, but .dat have missing entries, score file as 100%. 
//
		// calculate the results.
		// matched = hits from this entry in the database.  Can be a floating number, since filename+crc must match.
		// missed = number of items in the entry minus the hits
		// unknown = number of files in the zip file minus the hits.

	// score is based on 2 factor
		//  zip filecount / matching files 
		// +dat filecount / matching files

	if ( (m_exactMatches > 0) || (m_zipCRCmatches > 0) )// anything reportable?
		{
			matches = (m_exactMatches > m_zipCRCmatches) ? m_exactMatches : m_zipCRCmatches;	// get the better of the 2 results		

			// if we ignored any files, we have to subtract them from everywhere.
			m_topTen[0].datCount -=m_datIgnored;
			nFileCount -= m_zipIgnored;

			//how many files in this zip matched the dat?
			zipscore = (float)nFileCount / (float)matches; 
			if (zipscore > 1.0)	// 1/x function
				zipscore = ((float)matches / (float)nFileCount);

			//# files in zip - matching files - all skipped files
			int zipExtra = nFileCount-matches;
			if (zipExtra < 0)
			{// kludge! .dat file sometimes has files the zip doesn't, but they are ignored (file_id.diz for example)
				zipExtra = 0;
				matches = nFileCount;
			}
			unknown = zipExtra; //m_nFileCount - matches;  // this is hte same as zipExtra
			

			// how many roms in the zip matched the dat file?
			int datExtra = (m_topTen[0].datCount - matches); 
			if (datExtra < 0)	// kludge!  we can get more matches than entries in the dat when there are files in the ignore list and in the zip that are not in the dat
				datExtra = 0;
			missing = datExtra; //((theApp.m_fileData[m_topTen[0].pos].fileCount) - matches);  // this is the same as datExtra

			datscore = (float)m_topTen[0].datCount / (float)matches;
			if (datscore > 1.0)
				datscore = (float)matches / (float)m_topTen[0].datCount;
			score = (float)(datscore+zipscore) / (float)2.0;
			score *= 100;	// make it 0-100
			
			if ( (zipExtra > 0) && (datExtra==0) )	// case #2 - score file as 100%+
			{
				score = 100;
				score +=zipExtra;
			}

		if (score < 0) // juuuust in case
			score =0;

	// now examine the physical zip fileNAME we just scanned and see how it compares in the .dat
	// dump the folder and just dig the file out.
	// if there are duplicate files in different folders, we will always get the 1st one.
	if (sourceFile.Find('\\') != -1) 
		sourceFile = sourceFile.Right(sourceFile.GetLength() - (sourceFile.ReverseFind('\\')) -1 );

	// pull in the data from the zipArray
	//tempZIPdata = theApp.m_datZipFiles.GetAt(m_topTen[0].zipPos);
	//theApp.m_datZipList[theApp.m_datfileCount]. .filename= zipFilename;

	// perfect match, including zip filename?
	if ( (score == 100) && (m_topTen[0].filename == sourceFile) )
	{
		DWORD oldSts = theApp.m_datZipList[m_topTen[0].zipPos].status;
		oldSts &=0xff000000;
		theApp.m_datZipList[datIndex].status = (oldSts + STATUS_PERFECT);
	}
	else // all files, but .zip file incorrect
	if ( (score == 100) && (m_topTen[0].filename != sourceFile) )
	{
		DWORD oldSts = theApp.m_datZipList[m_topTen[0].zipPos].status;
		oldSts &=0xff000000;	
		theApp.m_datZipList[datIndex].status = (oldSts + STATUS_RENAME_ZIP_ONLY);
	}
	if ( (score < 100) && (missing == 0) && (unknown == 0) )
	{
		DWORD oldSts = theApp.m_datZipList[m_topTen[0].zipPos].status;
		oldSts &=0xff000000;
		theApp.m_datZipList[datIndex].status =( oldSts + STATUS_RENAME_ROMS);
	}

	if (missing < 0)	// yes.  this can happen when there is a crc match in a renamed file
	{
		int g=0;
	}

	if (missing > 0)
	{
		if (missing == unknown) // if the missing files exactly matches the # of unknown files (CRC collisions cause this), we are good.
		{		
			DWORD oldSts = theApp.m_datZipList[datIndex].status;
			oldSts &=0xff000000;		
			theApp.m_datZipList[datIndex].status = (oldSts + STATUS_CRC_COLLISION);	
		}
		else
		{
			DWORD oldSts = theApp.m_datZipList[datIndex].status;
			oldSts &=0xff000000;
			theApp.m_datZipList[datIndex].status = (oldSts + STATUS_MISSINGFILES);
		}
	}
	if (score > 100 )
	{
		DWORD oldSts = theApp.m_datZipList[datIndex].status;
		oldSts &=0xff000000;
		theApp.m_datZipList[datIndex].status = (oldSts + STATUS_EXTRAFILES);
	}


	}	// anything reportable





	return (int)score;
}

// compare this zip against every .dat entry
// zip's contents are already in global cmap
int CDOSCenterDlg::deepScan(CString sourceFile)
{
	/* wow, this didn't work at all.
	int	thisHit=0;
	ROMdata tempROMdata;
	CString zipName;

	m_topTenIdx = 0;	// flush out the topten
	for (int i=0; i<TOPARRAYSIZE; i++)
	{
		m_topTen[i].filename = "";
		m_topTen[i].score=0.0;
		m_topTen[i].zipPos = -1;
		m_topTen[i].dupes =0;
		m_topTen[i].perfects=0;
		m_topTen[i].crcMatch=0;
	}

	for (int i=0; i<theApp.m_datfileCount; i++)
	{
		checkDatvsZip(i, m_scannedZipFileCount, false);
		if (m_exactMatches > 0)
		{
			theApp.m_datZipListit = theApp.m_datZipList.find(tempROMdata.ptr2zipFileArray);
			zipName = theApp.m_datZipListit->second.filename;	// 2nd element is the 2nd thing stored in this map. weird stuff.
			thisHit = addtoTop10(zipName);	// pull the .zip name from the .dat and add it to our potential selection group - we may want to sort the list too.
		}
	}
	*/
	return 0;
}


// builds an array of best matches.  all we're trying to do is identify the best match in the .dat file.
// m_topTen[] array filled with the .dat entries that have the most CRC+filename matches
// returns true if CRC matched, false if not.
bool CDOSCenterDlg::scanCRCs(unsigned int crc, CString romName)
{	
	int	thisHit=0;
	bool status = false;
	CString tmp;
	CString scrc;
	CString zipName;
    LPCSTR ROMCRCKey;		// CRC is the key to storage
	ROMdata tempROMdata;	// temporary storage for the lookup
	ZIPdata tempZIPdata;		// temporary storeage for the zip file (from the .dat) the data came from
	
	// create a key out of the romName and CRC
	scrc.Format("%08x",crc);

	//if (theApp.m_ScanCRCFilename)
	//	tmp = romName+"_"+scrc; //crc!
	//else
	//	tmp=scrc;
//	tmp = scrc;

	ROMCRCKey = scrc;

	// zip files have "roms" in them.
	// rom can either be identified by CRC or by filename
	// we want to see both correct filenames but incorrect CRC
	// and correct CRC and incorrect filename.
	// map #1: CRC->rom name->zip name
	// map #2: rom name->crc->zip name
	// 
	// inside a zip, only rom filename must be unique, but crc may be duplicated.
	// (roms in folders will have folder as part of the name, so it's still unique)
	// 
	// Flow:
	//
	//   look up CRC.  if no hit, then the file is not in the .dat at all 
	//      If that's the case, we might have a filename that is a new CRC, so go check the filename map
	//         If filename match, look up ZIP->add to top 10, but note it somehow- (return 1)
	//      else return 0 (no match at all)
	//
	//   if CRC match, check filename. 
    //		 if match, look up ZIP->add to top 10 (return 3)
	//     else
	//       check for collisions, get new name, repeat loop
	//       no collision? look up ZIP->add to top 10 (return 2)
	//     
	// ie: filename+crc match, return  4
	//     crc match, no filename, return 2
	//     filename match, no CRC, return 1
	//     no CRC and no filename match, return 0
	//  scores > 0, look up the zip filename and add to top 10.
	//

	/*
		Flow #2 - faster, more better!
			Check CRC.  a match means this rom exists somewhere in the .dat
				if there are multiple .dat entries files with this CRC (collision) check up to MAX_CRC_COLLISIONS, adding each one to the top10 list
			if there is a unique CRC, make a record of the zip file dat entry that it belongs to. (the top10)
			we also check the filename against the CRC.  that would be a perfect match vs a CRC only match.  both are good, but perfects are more better.

	After scanning all CRCs of all roms in this zip, likely only 1 entry will be in the top ten, however there may be mixed CRCs in a zip, so we handle multiples.
	
	After we have a topten array of possible matches to the .dat file, we go to that .dat entry and re-compare the files in it against the zip.
	
	*/



	// look for the supplied CRC in the database.  This happens for things like drivers which are common across many games.
	// we support up to MAX_CRC_COLLISIONS to exist in the database.

	// zip files may have the following conditions:
	// 1) CRC + filename match
	// 2) CRC match, filename mismatch
	// 3) multiple files in the zip with different names but the same CRC.  
	CString oldname = "";
	while (theApp.m_ROMDATEntryCRC.Lookup(ROMCRCKey, tempROMdata))	// CRC hit?
	{	
		status = true;
		// get the zip filename from the dat where this rom is located
		theApp.m_datZipListit = theApp.m_datZipList.find(tempROMdata.ptr2zipFileArray);
		zipName = theApp.m_datZipListit->second.filename;	// 2nd element is the 2nd thing stored in this map. weird stuff.
		thisHit = addtoTop10(zipName);	// pull the .zip name from the .dat and add it to our potential selection group
		if (oldname != zipName)
		{
		// we only want to apply points for this incoming CRC once, even if there are multiple matching CRCs in the database.
			oldname=zipName;	// check the name, cuz the hit# could change if the array was sorted.
			if (tempROMdata.fileName.MakeLower() == romName)	// filename match too?
				m_topTen[thisHit].perfects++;	// name+crc match. 
			else
				m_topTen[thisHit].crcMatch++;	// award only 0.65 of a point
		}
			// check for collisions in the CRC database.
			if (tempROMdata.collision == true)
			{
				tmp = ROMCRCKey;
				theApp.makeNewKey(tmp);	// modify the filename_CRC to go to the next entry; start this loop all over again
				ROMCRCKey = tmp;
			}
			else
				break;

	}

/* single CRC version
	if (theApp.m_ROMDATEntryCRC.Lookup(ROMCRCKey, tempROMdata))	// CRC hit?
	{	
		status = true;
		// get the zip filename from the dat where this rom is located.
		theApp.m_datZipListit = theApp.m_datZipList.find(tempROMdata.ptr2zipFileArray);
		zipName = theApp.m_datZipListit->second.filename;	// 2nd element is the 2nd thing stored in this map. weird stuff.
		thisHit = addtoTop10(zipName);	// pull the .zip name from the .dat and add it to our potential selection group

		// before giving any points, we have to check for CRC matches within the same zip file.
		if (!tempROMdata.collision)
		{
			if (tempROMdata.fileName.MakeLower() == romName)	// filename match too?
				m_topTen[thisHit].perfects++;	// name+crc match.  nice. - note we will get points below for a filename+crc match too!
			else
				m_topTen[thisHit].crcMatch++;	// crc ok, name is wrong
		} // not collision
		//else
		//	 m_topTen[thisHit].dupes++;	// a CRC matched, but it is also in another .dat entry. we throw these away.
	}

*/
/*
	// now check names in the .dat  - these are supplemental if we have a rom name but the crc doesn't match
	// maybe grab the best performer from the top ten and also scan names only?
	ROMFilenameKey = romName;
	while(theApp.m_ROMDATEntryName.Lookup(ROMFilenameKey, tempROMdata))
	{	
		//status = true;
		// get the zip filename from the dat where this rom is located
		theApp.m_datZipListit = theApp.m_datZipList.find(tempROMdata.ptr2zipFileArray);
		zipName = theApp.m_datZipListit->second.filename;	// 2nd element is the 2nd thing stored in this map. weird stuff.
		thisHit = addtoTop10(zipName);
		if (thisHit == 0xffffffff)
			{ // possible solution to this: if any one of the toptenIdx entries has significantly more hits than creating a new entry,
				// we can probably stop adding new entries into the topten.  
				AfxMessageBox("Ack!  We've run out of space trying to store possible matches for this file:"+romName+"\rYou might try adding that filename (without CRC) to your ignore list." , MB_ICONERROR, 0);
			}
		
		if (tempROMdata.crc != crc)	// crc match too?  we should have caught that above
			m_topTen[thisHit].nameMatch++;	// name+crc match.  nice. // we get a total of 4 points for name+crc
		
		// check for collisions in the CRC database
		if (tempROMdata.collision == true)
		{
			tmp = ROMFilenameKey;
			theApp.makeNewKey(tmp);	// modify the filename_CRC to go to the next entry; start this loop all over again
			ROMFilenameKey = tmp;
		}
		else
			break;
	}	
	*/

	return status;	// this file/crc has been located	
}
// add an entry to the top ten (which is now 20)
// fixme- if we get more than ARRAYSIZE hits, we should sort it as we go so the best always gets to the top.
int CDOSCenterDlg::addtoTop10(CString zipName)
{
	int thisHit;
	// have we seen this zip filename before? 
	// increment the counter and that's it.
	for (thisHit=0; thisHit<TOPARRAYSIZE; thisHit++)
		{
			if (m_topTen[thisHit].filename == zipName)
				{
					zipName = "";	// nuke name so it doesn't get re-added to the top ten list
					break;
				}
		}


	// else, this is a new entry from the .dat file which also has a matching CRC to this file.
	// like when there are [a1] versions of a zip, this will happen often.
	if (zipName != "") // new hit.  save some stuff
		{
			// if we're about to run out of room in the top ten list, give it a quick score-n-sort to move the better hits up
			if (m_topTenIdx == (TOPARRAYSIZE-1))
			{
				sortTopTen();	// put the best of the best at the top.  better matches in the dat should float to the top
			}

			m_topTen[m_topTenIdx].filename = zipName;	// save off the zip filename
			m_topTen[m_topTenIdx].datCount = theApp.m_datZipListit->second.fileCount; // and the numer of roms in this zip
			m_topTen[m_topTenIdx].zipPos =  theApp.m_datZipListit->first; // and the pointer to the zip file (this is the first item in the map (the key))
			m_topTen[m_topTenIdx].crcMatch=0;
			m_topTen[m_topTenIdx].dupes=0;
			m_topTen[m_topTenIdx].perfects=0;
			//m_topTen[m_topTenIdx].score=0;
			m_topTen[m_topTenIdx].zipCount = m_scannedZipFileCount;
			// zipscore is the number of files in this zip vs the number in the dat we've picked.  it can never be >1.0
			// this helps weed out compilations which are supersets of individual games. 
			float zipscore = (float)(m_topTen[m_topTenIdx].datCount / (float)m_topTen[m_topTenIdx].zipCount);
			if (zipscore > 1.0)	// 1/x function
				zipscore = ((float)m_topTen[m_topTenIdx].zipCount / (float)m_topTen[m_topTenIdx].datCount);
			m_topTen[m_topTenIdx].zipScore = zipscore;
			thisHit= m_topTenIdx;
			if (m_topTenIdx < (TOPARRAYSIZE-1))
				m_topTenIdx++;
		}

	return thisHit;	// return index of this zip filename in the top ten array
}

void CDOSCenterDlg::sortTopTen()
{
  int i, j;
  int temp;
  CString stemp;
  float ftemp;

	for (int ii=0; ii<TOPARRAYSIZE; ii++)
		{
		// 3 elements are used: # of perfect matches in this zip against this dat entry
		//                      # of crc matches in this zip against this dat entry
		//                      # of of roms in the zip vs. the # in the dat entry
		//int matches = (m_topTen[ii].perfects > m_topTen[ii].crcMatch) ? m_topTen[ii].perfects : m_topTen[ii].crcMatch;	// get the better of the 2 results		
		//if (matches>0)
		//{	//how many files (roms) in this zip matched the dat?

		float score = (float)m_topTen[ii].crcMatch * 0.65;
		score += ((float)m_topTen[ii].perfects * (float)m_topTen[ii].zipScore); 
		score *=(float)m_topTen[ii].zipScore;
		m_topTen[ii].score=score; 
		}


  // sort it by score, if we have a match, sort by perfects
  for (i = (TOPARRAYSIZE - 1); i >= 0; i--)		// yep this is a bubble sort.
  {

	for (j = 1; j <= i; j++)
    {
		if (m_topTen[j].filename.GetLength() > 0)
		{
			if ( (m_topTen[j-1].score) < (m_topTen[j].score) )
			{
				ftemp = m_topTen[j-1].score;
				m_topTen[j-1].score = m_topTen[j].score;
				m_topTen[j].score = ftemp;

				ftemp = m_topTen[j-1].zipScore;
				m_topTen[j-1].zipScore = m_topTen[j].zipScore;
				m_topTen[j].zipScore = ftemp;

				stemp = m_topTen[j-1].filename;
				m_topTen[j-1].filename = m_topTen[j].filename;
				m_topTen[j].filename = stemp;

				temp = m_topTen[j-1].zipPos;
				m_topTen[j-1].zipPos = m_topTen[j].zipPos;
				m_topTen[j].zipPos = temp;

				temp = m_topTen[j-1].perfects;
				m_topTen[j-1].perfects = m_topTen[j].perfects;
				m_topTen[j].perfects = temp;

				temp = m_topTen[j-1].crcMatch;
				m_topTen[j-1].crcMatch = m_topTen[j].crcMatch;
				m_topTen[j].crcMatch = temp;

				temp = m_topTen[j-1].dupes;
				m_topTen[j-1].dupes = m_topTen[j].dupes;
				m_topTen[j].dupes = temp;

				temp = m_topTen[j-1].datCount;
				m_topTen[j-1].datCount = m_topTen[j].datCount;
				m_topTen[j].datCount = temp;
			}
		} // if there's data here
    }
  }

}




// scan an entire folder worth of files
void CDOSCenterDlg::scanAllFiles()
{
	for	(int i=0; i<theApp.m_leftSideList.GetItemCount(); i++)
		theApp.m_leftSideList.SetItemState(i, LVNI_SELECTED,LVIS_SELECTED);

	scanSelectedZips();
	theApp.m_leftSideList.SetFocus();
	for	(int i=0; i<theApp.m_leftSideList.GetItemCount(); i++)
		theApp.m_leftSideList.SetItemState(i, 0, LVIS_SELECTED);

	theApp.m_leftSideList.SetItemState(0, LVNI_SELECTED, LVNI_SELECTED);	
}

// checks a given file to see if it should be ignored or not, based on name, file size and crc.
// returns TRUE if file should be skipped, false if not.
// database of skippable files is built off the settings and tools->ignore database
bool CDOSCenterDlg::skipafile(CString filename, CString ext, unsigned int crc, unsigned int fileSize)
{
	filename.MakeLower();
	ext.MakeLower();
	
	if (theApp.m_ignoreOn == false)
		return false;

	if ((theApp.m_minFilesize != -1) && (fileSize < theApp.m_minFilesize))
		return true;

	for (int i=0; i<theApp.m_ignoreTheseCount; i++)
	{
		// check for filename or any filename
		if ((filename == theApp.m_ignoreThese[i].filename.MakeLower() ) || (theApp.m_ignoreThese[i].filename == "*"))
		{
			// check extension, or any extension
			if ( (ext == theApp.m_ignoreThese[i].ext.MakeLower() ) || (theApp.m_ignoreThese[i].ext == "*") )
			{
				if ( (theApp.m_ignoreThese[i].crc == -1) || (theApp.m_ignoreThese[i].crc == crc) ) // any CRC or match?
					return true;
			}

		}
	}
	return false;
}



// keep app from closing upon hitting the enter key.
void CDOSCenterDlg::OnBnClickedOk()
{
	// TODO: Add your control notification handler code here
	//OnOK();
}

// checkboxes for hiding files in the zip listing window (right side)
void CDOSCenterDlg::OnBnClickedHidematches()
{
	OnNMDblclkZipFileList(NULL,NULL);
}
void CDOSCenterDlg::OnBnClickedHidemissing()
{
	OnNMDblclkZipFileList(NULL,NULL);
}

void CDOSCenterDlg::OnBnClickedHideunknown()
{
	OnNMDblclkZipFileList(NULL,NULL);
}

void CDOSCenterDlg::OnBnClickedHidealts()
{
	OnNMDblclkZipFileList(NULL,NULL);
}


// small popup for when user right clicks something onthe zip details window side.
void CDOSCenterDlg::OnNMRclickRightSideList(NMHDR *pNMHDR, LRESULT *pResult)
{
	*pResult = 0;
	int count=0;
	CString tmp;
	FILE* outFile;
	int nIndex=-1;

	CPoint point;                                            
     ::GetCursorPos(&point); //where is the mouse?


	CMenu menu; //lets display our context menu :) 

    DWORD dwSelectionMade;                                       
    VERIFY(menu.LoadMenu(IDR_MENU2) );  

	CMenu *pmenuPopup = menu.GetSubMenu(0);


	 // no files in the list?  no menu
	if (theApp.m_zipDetailsList.GetItemText(0,1) == "")
		return;

	// gray the "move files up" option if this zip is not in a nested folder
	if (theApp.m_zipIsFoldered == false)
		pmenuPopup->EnableMenuItem(ID_ZIPCOMMANDS_MOVEFILESUP, MF_GRAYED+MF_BYPOSITION);

	// gray view and compare selection if many files are selected.
	count=0;
	while (1) 
		{
			nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);
			if (nIndex == -1)
				break;
			count++;
		}
	if (count >1)
	{
	 pmenuPopup->EnableMenuItem(3, MF_GRAYED+MF_BYPOSITION);	// kill the compare selection
	 pmenuPopup->EnableMenuItem(4, MF_GRAYED+MF_BYPOSITION);	// kill the view selection
	}
	
	if (theApp.m_DATfileLoaded == false)
	{
		pmenuPopup->EnableMenuItem(1, MF_GRAYED+MF_BYPOSITION);	// kill the add2dat option
		pmenuPopup->EnableMenuItem(2, MF_GRAYED+MF_BYPOSITION);	// kill the add2dat option

	}



	nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);
	if (theApp.m_zipDetailsList.GetItemText(0, COLORCOL) == COLOR_PBROWN)	// if we've dropped our warning in the list, skip over it.
		nIndex--;
	if (nIndex<0)
		return;

	ASSERT(pmenuPopup != NULL);                                       

	 
	dwSelectionMade = pmenuPopup->TrackPopupMenu( (TPM_LEFTALIGN|TPM_LEFTBUTTON|
                                                       TPM_NONOTIFY|TPM_RETURNCMD),
                                                       point.x, point.y, this
                                );                                



	 if (dwSelectionMade == ID__FILEINFO)
	 {
//		int zipPosPtr = theApp.m_tmpzipList[nIndex].ptr2zipFileArray;
		CString romName = theApp.m_tmpzipList[nIndex].newFileName;
//		CString zipName = theApp.m_datZipList[zipPosPtr].filename;
		int status = theApp.m_tmpzipList[nIndex].status;
		if (theApp.m_tmpzipList[nIndex].status == STATUS_ROM_IGNORED)
			tmp = "This type of file is in your ignore list.";
		if ((theApp.m_tmpzipList[nIndex].status & STATUS_ROM_CRC_MATCH+STATUS_ROM_FILENAME_MATCH) == STATUS_ROM_CRC_MATCH)
			tmp = "This filename is incorrect according to the DAT file.\r\nShould be:"+romName;
		if (theApp.m_zipDetailsList.GetItemText(nIndex, COLORCOL) == COLOR_RED_IGNORED)
			tmp = "According to the DAT, this file is missing from the scanned zip, but it's in your ignore list so we don't really care.";	
		if (theApp.m_zipDetailsList.GetItemText(nIndex, COLORCOL) == COLOR_GREEN)	// could also check status bits
			tmp = "CRC and filename match target DAT file";
		if (theApp.m_zipDetailsList.GetItemText(nIndex, COLORCOL) == COLOR_BROWN)
			tmp = "CRC mismatch for this file. Filename is correct.";
			
		if (theApp.m_tmpzipList[nIndex].status == STATUS_ROM_ELSEWHERE)
		{
			tmp = "This file is found in different zip in the DAT:\r\n"+romName+"\r\nSwitch to this zip?"; // repurposed romname to mean different zip file for this condition
			int choice = AfxMessageBox(tmp, MB_ICONWARNING | MB_YESNO, 0);
			if ( choice == IDYES )
			{
				nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
				theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,romName);
				OnNMDblclkZipFileList(NULL, NULL);
			}
			tmp="";	// avoid the message box below
		}

		if (theApp.m_tmpzipList[nIndex].status == 0)
			tmp = "The CRC of this file is not in the DAT.\r\nUnknown file";
		if (theApp.m_zipDetailsList.GetItemText(nIndex, COLORCOL) == COLOR_RED)
			tmp = "This zip is missing this file.";
		
		if (!tmp.IsEmpty())
			AfxMessageBox(tmp , MB_ICONINFORMATION, 0);
	 }




	 if ( (dwSelectionMade == ID_TOFILE_NOCOLOR) || (dwSelectionMade == ID_TOCLIPBOARD_NOCOLOR) )
	 {
		CString logData=theApp.m_currentlyTaggedZipFile+"\r\n";
		while (	theApp.m_zipDetailsList.GetItemText(count,1) != "") 
		{
			if  (theApp.m_zipDetailsList.GetItemText(count,4) != "-alternate-") 
			{
				logData +=theApp.m_zipDetailsList.GetItemText(count,1)+".";	// filename
				logData +=theApp.m_zipDetailsList.GetItemText(count,2)+" ";	// ext
				logData +=theApp.m_zipDetailsList.GetItemText(count,3)+" ";	// size
				logData +=theApp.m_zipDetailsList.GetItemText(count,4)+" ";	// date
				logData +=theApp.m_zipDetailsList.GetItemText(count,5)+" ";	// crc
				logData +="\r\n";
			}
			count++;
		}
	 	if (dwSelectionMade == ID_TOCLIPBOARD_COLOR)
		{
			CopyToClipboard(logData);
			return;
		}
		outFile = fopen("c:\\ziplist.txt","wb");
		fwrite(logData, sizeof( char ), logData.GetLength(), outFile );
		fclose(outFile);
		AfxMessageBox("File listing exported to C:\\ziplist.txt" , MB_ICONINFORMATION, 0);
	 }
	
	if ( (dwSelectionMade == ID_TOFILE_COLOR) || (dwSelectionMade == ID_TOCLIPBOARD_COLOR) )
	{
		//[color=blue]This text is blue[/color]
		CString logData=theApp.m_currentlyTaggedZipFile+"\r\n";
		while (	theApp.m_zipDetailsList.GetItemText(count,1) != "") 
		{
			if  (theApp.m_zipDetailsList.GetItemText(count,4) != "-alternate-") 
			{
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_HIDE)
					continue;
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_RED)
					logData+="[color=red]";
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_GREEN)
					logData+="[color=green]";
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_BLACK)
					logData+="[color=black]";
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_YELLOW)
					logData+="[color=yellow]";
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_BLUE)
					logData+="[color=blue]";
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_PURPLE)
					logData+="[color=purple]";
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_BROWN)
					logData+="[color=brown]";
				if (theApp.m_zipDetailsList.GetItemText(count,0) ==COLOR_GRAY)
					logData+="[color=gray]";
				
				logData +=theApp.m_zipDetailsList.GetItemText(count,1)+".";	// filename
				logData +=theApp.m_zipDetailsList.GetItemText(count,2)+" ";	// ext
				logData +=theApp.m_zipDetailsList.GetItemText(count,3)+" ";	// size
				logData +=theApp.m_zipDetailsList.GetItemText(count,4)+" ";	// date
				logData +=theApp.m_zipDetailsList.GetItemText(count,5)+" ";	// crc
				logData +="[/color]\r\n";

			}
			count++;
		}
	 	if (dwSelectionMade == ID_TOCLIPBOARD_COLOR)
		{
			CopyToClipboard(logData);
			return;
		}
		outFile = fopen("c:\\ziplist.txt","wb");
		fwrite(logData, sizeof( char ), logData.GetLength(), outFile );
		fclose(outFile);
		AfxMessageBox("File listing exported to C:\\ziplist.txt" , MB_ICONINFORMATION, 0);
	 }
	

	 // temporarily add this entry to the internal database
	 if (dwSelectionMade == ID__ADDTODATABASE)
	 {
		add2database();
	 }

	// permanently add this entry to the .dat file
	 if (dwSelectionMade == ID__ADDTODATFILE)
	 {
		 add2database();
		 add2datFile();
	 }		

	 if (dwSelectionMade == ID__VIEWFILE)
		 hexViewFile();

	
	 if (dwSelectionMade == ID__COMPARE)
		 compare2Files();

	 if (dwSelectionMade == ID__ADDTOIGNORELIST)
		 add2Ignore();

	 if (dwSelectionMade == ID_ZIPCOMMANDS_DELETE)
		 deleteFileInZip();

	 if (dwSelectionMade == ID_ZIPCOMMANDS_RENAME)
		 renameFileInZip();

	 if (dwSelectionMade == ID_ZIPCOMMANDS_MOVEFILESUP)
		 unNestZipFile();

	 if (dwSelectionMade == ID_ZIPCOMMANDS_EXTRACTTOZIP)
		 zip2NewFile();

	 pmenuPopup->DestroyMenu(); 

}


void CDOSCenterDlg::add2database()
{
	CSettingsandTools CnT;
	ROMdata tempROMdata;	// temporary storage for the lookup
	int count=0;
	unsigned int size, date;
	CString name, scrc, tmp;
	CString color;

	CString f= theApp.m_datZipList[theApp.m_datfileCount].filename;
	theApp.m_datZipList[theApp.m_datfileCount].filename= theApp.m_currentlyTaggedZipFile;	// store the zip filename inside the structure inside the map.
	

	//	theApp.m_fileData[theApp.m_datfileCount].filename = 
//	theApp.m_datZipListit = theApp.m_datZipList.find(theApp.m_datfileCount);
//	CString	zipName = theApp.m_datZipListit->second.filename;	
	
	while (1)
	{
		color = theApp.m_zipDetailsList.GetItemText(count,0);
		if ( (color != COLOR_RED) && (color != COLOR_PBROWN) )
		{
			name = theApp.m_zipDetailsList.GetItemText(count,1);	// filename
			tmp = theApp.m_zipDetailsList.GetItemText(count,2);
			if (tmp.GetLength() !=0)
				name+="."+theApp.m_zipDetailsList.GetItemText(count,2);	// ext

			scrc = theApp.m_zipDetailsList.GetItemText(count,5);	// crc
			tmp = theApp.m_zipDetailsList.GetItemText(count,3);	// size
			sscanf(tmp,"%x",&size);	
			date = CnT.String2Date(theApp.m_zipDetailsList.GetItemText(count,4)); //date
			CnT.rom2datmap(name, size, 0, true, date, scrc, theApp.m_datfileCount, count);	
		}
	
		tmp = theApp.m_zipDetailsList.GetItemText(count,0);
		count++;
		if (tmp.GetLength() == 0)
			break;
		
	}
	
	theApp.m_datZipList[theApp.m_datfileCount].fileCount = count;	// store the # of ROMs the zip contains
	theApp.m_datZipList[theApp.m_datfileCount].status = 0;
	theApp.m_datfileCount++;	// global counter of # of items in the .dat file

}

// add the currently open zip file to the .dat file
// this is kinda slow and stupid, since it opens and closes the .dat file everytime it's called.
void CDOSCenterDlg::add2datFile()
{
	CSettingsandTools tools;
	tools.Add2DatFile();
}
// from the right side zip details list, add an entry to the ignore list.
void CDOSCenterDlg::add2Ignore()
{
	CFileStuff fileStuff;
	CString tmp;
	int pos, nIndex;
	FILE* outFile;
	CString fileData;
	nIndex= -1;
	nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);

	pos = theApp.m_ignoreFileData.Find("min_filesize = ");
	if (pos == -1)
	{
		AfxMessageBox("Failed to open DCIgnore.ini!  Should be in the same path as DOSCenter.exe.", MB_ICONEXCLAMATION, 0);
		return;
	}

	while (1)
	{
		tmp = theApp.m_zipDetailsList.GetItemText(nIndex,1);	// filename
		if (tmp.Find('\\') != -1) 
			tmp = tmp.Right(tmp.GetLength() - (tmp.ReverseFind('\\')) -1 );
	
		theApp.m_ignoreFileData+=tmp+", ";
		theApp.m_ignoreFileData+=theApp.m_zipDetailsList.GetItemText(nIndex,2)+", ";	// ext
		theApp.m_ignoreFileData+=theApp.m_zipDetailsList.GetItemText(nIndex,5)+"\r\n";	// crc
	
	
	
		outFile = fopen(theApp.g_appPath+"\\DCignore.ini","wb");
		theApp.m_ignoreFileData.Replace("\n","\r\n");
		fwrite(theApp.m_ignoreFileData, sizeof( char ), theApp.m_ignoreFileData.GetLength(), outFile );
		fclose(outFile);
		
		// point to next item		
		nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
	}

	theApp.m_ignoreStartPos = 0;
	theApp.m_reloadIgnore = true;
	populateIgnoreList();
	

}

void CDOSCenterDlg::OnLvnKeydownZipdetailslist(NMHDR *pNMHDR, LRESULT *pResult)
{
	LPNMLVKEYDOWN pLVKeyDow = reinterpret_cast<LPNMLVKEYDOWN>(pNMHDR);
	// TODO: Add your control notification handler code here
	*pResult = 0;

	if (pLVKeyDow->wVKey == 0x2e) // delete key - delete and entry from a zip file
		deleteFileInZip();

	if ( (HIBYTE(GetKeyState(VK_CONTROL))) && (pLVKeyDow->wVKey == 65) )	// ctrl-A
	{
		for	(int i=0; i<theApp.m_leftSideList.GetItemCount(); i++)
			theApp.m_zipDetailsList.SetItemState(i, LVNI_SELECTED,LVIS_SELECTED);
		
	}
	if (pLVKeyDow->wVKey == 0x71) // F2 - rename
		renameFileInZip();

}

void CDOSCenterDlg::OnLvnKeydownLeftsidelist(NMHDR *pNMHDR, LRESULT *pResult)
{
	LPNMLVKEYDOWN pLVKeyDow = reinterpret_cast<LPNMLVKEYDOWN>(pNMHDR);
	*pResult = 0;

	int nIndex=-1;
	int lastDeleted=0;
	CString source,dest;
	CString tmp;
	int count=0;


	if ( (HIBYTE(GetKeyState(VK_CONTROL))) && (pLVKeyDow->wVKey == 65) )	// ctrl-A
	{
		for	(int i=0; i<theApp.m_leftSideList.GetItemCount(); i++)
			theApp.m_leftSideList.SetItemState(i, LVNI_SELECTED,LVIS_SELECTED);
		
	}

	if (pLVKeyDow->wVKey == 0x71) // F2 key
	{
		// count number of items in list-popup verify message.
		count=0;
		while (1) 
			{
				nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;
				count++;
			}
		if (count > 0)
			renameZipFileWithPopUpDialog();
	}

	if (pLVKeyDow->wVKey == 0x2e) // delete key
	{	
		// count number of items in list-popup verify message.
		count=0;
		while (1) 
			{
				nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;
				count++;
			}
		tmp.Format("Delete %d file(s)?", count);
		int choice = AfxMessageBox(tmp, MB_ICONWARNING | MB_YESNO, 0);
			if ( choice == IDNO )
				return;

		nIndex=-1;	// ok then, delete away!
		
		while (1) 
		{
			nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
			if (nIndex == -1)
				break;
			else
			{
				source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
				remove(m_SourcePath+source);
				theApp.m_leftSideList.DeleteItem (nIndex);
			}
		}
	} // delete key


	if (pLVKeyDow->wVKey == 0x53)	// S key
		scanSelectedZips();

	if (pLVKeyDow->wVKey == 0x4d)	// M key
		mergeZipFiles();

	if (pLVKeyDow->wVKey == 0x74) // F5 - refresh dir
		updateZipList();
}

// settings and tools popup+exchange
void CDOSCenterDlg::OnBnClickedSettingsbtn()
{
	CSettingsandTools dlg;
	dlg.DoModal();
	theApp.m_tmpWorkingFolder +="\\DOSCenter";
	if ((m_datview) && (!theApp.m_datParsed))	// just (re)loaded a .dat file
		 populateDATFileDataView();

}

// given a zip, locate the original from the source folder and try and dig out the same file that we're looking at.
void CDOSCenterDlg::compare2Files()
{
	UZ_FileInfo info;
	CUnzipper tmp_uz;
	int nIndex;
	CString filename, txt, ascii, targetZipName, tmpFile;
	CString compareFolder = theApp.m_tmpWorkingFolder+"\\compare";
	CFileStuff files;
	CString srcData, tgtData;
	CHexCompareDlg dlg;
	bool miscompare = false;
	unsigned int lastSpot = 0;


	FILE* srcFile;	// file from DOS collection
	FILE* tgtFile;	// file we're comparing

	// get the path to the collection folder.   
	if (theApp.m_collectionPath.GetLength() == 0)
	{
		AfxMessageBox("Error, no path to the DOS collection has been defined.\r\nUse the settings and tools button to set it.", MB_ICONSTOP, 0);
		return;
	}

	// get the filename inside the zip that we're concerned with.
	nIndex = theApp.m_zipDetailsList.GetNextItem(-1, LVNI_SELECTED);
	filename = theApp.m_zipDetailsList.GetItemText(nIndex,1);
	filename +="."+theApp.m_zipDetailsList.GetItemText(nIndex,2);	// extension

	if (theApp.m_zipDetailsList.GetItemText(nIndex,COLORCOL) == COLOR_RED)	// don't allow us to 2x click a missing file.
		return;

	// get the filename from the .dat
	nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
	targetZipName = theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL);

	// dump the folder and just dig the file out.
	// if there are duplicate files in different folders, we will always get the 1st one.

	txt = filename.Right(filename.GetLength()-filename.ReverseFind('\\')-1);
	if (txt.GetLength() > 0)
		filename= txt;





	// open zip file that we're examining
	m_uz.OpenZip(m_SourcePath+theApp.m_currentlyTaggedZipFile);
	m_uz.GotoFile(filename,1); // ignore path
	m_uz.GetFileInfo(info);		// just in case
	

	if (!m_uz.UnzipFile(theApp.m_tmpWorkingFolder, 1))	// ignore file path
	{
		AfxMessageBox("Ack.  An unzip error occurred. This zip file might be old and compressed with Shrink based compression. \
		  \r\nYou should try to refresh/recompress this zip file with winRAR or similar and try again." , MB_ICONERROR, 0);
		m_uz.CloseZip();
		return;
	}
	m_uz.CloseZip();


	// open the source zip file.  If we can't find it, we open a browse dialog	
	if ( (targetZipName == "perfect!") || (targetZipName == "no good matches") )
		targetZipName = "";

	if (!tmp_uz.OpenZip(theApp.m_collectionPath+targetZipName))
	{
		if (targetZipName.GetLength() > 0)
			AfxMessageBox("Can't find "+theApp.m_collectionPath+targetZipName, MB_ICONERROR, 0);
		
		tmpFile = "";
		LPCTSTR FileFilter = "zip files (*.zip)\0*.zip\0"; 
		LPCTSTR FileExt = "zip";
		files.m_windowTitle = "Locate a zip file to compare against...";
		if (files.UserBrowseOpen(&tmpFile, FileFilter, FileExt))
		{
			if (!tmp_uz.OpenZip(tmpFile))
				return;
		}
		else
			return; // user has cancelled.

	}
	tmp_uz.GotoFile(filename,1); // ignore path
	if (!tmp_uz.UnzipFile(compareFolder, 1))	// ignore file path
	{
		AfxMessageBox("Ack.  An unzip error occurred. File not found or the zip may be corrupt." , MB_ICONERROR, 0);
		tmp_uz.CloseZip();
		return;
	}
	tmp_uz.CloseZip();



	//
	// ok, now we've got 2 files on the hard drive.  One from the investigated zip, one from the DOS collection.  yay!
	//

	
	unsigned int size = info.dwUncompressedSize + (16 - (info.dwUncompressedSize & 0xf));
	char* srcBuffer = new char[size];
	char* tgtBuffer = new char[size];

	// now open the file and display it in the popup viewer
	srcFile = fopen(compareFolder+"\\"+filename,"rb");
	tgtFile = fopen(theApp.m_tmpWorkingFolder+"\\"+filename,"rb");

	memset(srcBuffer,0,size);
	memset(tgtBuffer,0,size);

	if (srcFile != NULL)
		fread(srcBuffer,info.dwUncompressedSize,1 ,srcFile);
	if (tgtFile != NULL)
		fread(tgtBuffer,info.dwUncompressedSize,1 ,tgtFile);

	// close both files
	if (srcFile != NULL)
			fclose(srcFile);	
	if (tgtFile != NULL)
			fclose(tgtFile);	

	//
	// compare 'em
	//
	
	for (unsigned int i=0; i<size; i++)
		if ( (unsigned char)srcBuffer[i] != (unsigned char)tgtBuffer[i])
		{
			miscompare = true;
			srcData = "";
			tgtData = "";
			// roll back viewer so that we get at least 3 lines of data on the screen, so that different data is always on line 2
			i = (i & 0xfffffff0) - 16;
			if (i < 0)
				i=0;
			
			// convert data into nice hex display with offset and ascii bytes.
			for (int q=0; q<16 * 3; q++)	// 3 lines of display
			{
				if ((q & 0xf) == 0x00)	// offset
				{
					txt.Format("%08x", i+q);
					srcData+=txt+"  ";
				}
				txt.Format("%02X", (unsigned char)srcBuffer[i+q]);
				srcData+=txt+" ";

				if ((unsigned char)srcBuffer[i+q] < 31)	// ascii
					ascii+=".";
				else 
					ascii+=srcBuffer[i+q];

				if ((q & 0xf) == 0xf) // add ascii and CRLF
				{
					srcData+="  "+ascii+"\r\n";	
					ascii="";
				}
				if ( ((q & 0xf) !=0xf) && ((q & 7) == 7)) srcData+="- ";
			}

			// convert data into nice hex display with offset and ascii bytes.
			for (int q=0; q<16 * 3; q++)	// 3 lines of display
			{
				if ((q & 0xf) == 0x00)	// offset
				{
					txt.Format("%08x", i+q);
					tgtData+=txt+"  ";
				}
				txt.Format("%02X", (unsigned char)tgtBuffer[i+q]);
				tgtData+=txt+" ";

				if ((unsigned char)tgtBuffer[i+q] < 31)	// ascii
					ascii+=".";
				else 
					ascii+=tgtBuffer[i+q];

				if ((q & 0xf) == 0xf) // add ascii and CRLF
				{
					tgtData+="  "+ascii+"\r\n";	
					ascii="";
				}
				if ( ((q & 0xf) !=0xf) && ((q & 7) == 7)) tgtData+="- ";
			}


			// throw the contents over the wall
			if (lastSpot == 0)
				dlg.m_prev = -1; // disable the previous search button
			dlg.m_windowTitle = filename;
			dlg.m_srcZipFilename = theApp.m_collectionPath+targetZipName;
			dlg.m_tgtZipFilename = m_SourcePath+theApp.m_currentlyTaggedZipFile;
			dlg.m_srcDataTxt = srcData;
			dlg.m_tgtDataTxt = tgtData;
			dlg.m_makeDif = 0;
			if (dlg.DoModal() == 2)	// cancel button hit?
				break;
			if ( (dlg.m_next == 1) && (dlg.m_prev == 0) )
			{
				lastSpot = i;
				i=i+(4*16);
			}
			if ( (dlg.m_next == 0) && (dlg.m_prev == 1) )
				i = lastSpot;

			if (dlg.m_makeDif == 1)	// generate an FC output and throw it in a popup window
			{
				
				srcData = "Comparing "+filename+" and "+filename+"\r\n";
				for (unsigned int i=0; i<size; i++)
					if ( (unsigned char)srcBuffer[i] != (unsigned char)tgtBuffer[i])
					{
						txt.Format("%08x ", i);
						srcData+=txt;
						txt.Format("%02X ", (unsigned char)srcBuffer[i]);
						srcData+=txt;
						txt.Format("%02X ", (unsigned char)tgtBuffer[i]);
						srcData+=txt+"\r\n";
					}
				CPopupViewerTxtDlg dlg;
				dlg.m_viewerTxt = srcData;
				dlg.m_fileNameViewer = "FC output";
				dlg.DoModal();
				break;
			}

		}

	if (!miscompare)
		AfxMessageBox("Files are identical." , MB_ICONINFORMATION, 0);

	delete []srcBuffer;
	delete []tgtBuffer;

	// clean up any leftovers unzips
	CreateDirectory(_T(compareFolder), NULL); // just in case
	files.DeleteDirectory(compareFolder);

}

void CDOSCenterDlg::populateIgnoreList()
{
	// open ignore file if it exists and populate the list control
	CFileStuff fileStuff;
	FILE* inFile;
	CString data;
	CString line;
	CString filename, ext, crc; //, size
	int pos;

	inFile = fopen(theApp.g_appPath+"\\DCignore.ini","r");
	if (inFile == NULL)
	{
		AfxMessageBox("Failed to open DCIgnore.ini!  Should be in the same path as DOSCenter.exe.", MB_ICONEXCLAMATION, 0);
		return;
	}

	fileStuff.loadFile(inFile, theApp.m_ignoreFileData);
		
	// close input file
	fclose(inFile);	

	

	data = theApp.m_ignoreFileData;
	data.Replace("\n\r","\r");
	data.Replace("\n","\r");
	data +="\r";

	theApp.m_ignoreStartPos = 0;
	theApp.m_ignoreTheseCount = 0;
	for (int i=0; i<data.GetLength(); i++)
	{
		pos = data.Find("\r",i);
		line = data.Mid(i,pos-i);
		i+=line.GetLength();
		//i++;	// skip the CR
		line.Trim();

		if (line.Left(1) == ";")
			continue;
		if (line.GetLength() == 0)
			continue;

		
		if (line.Find("min_filesize") != -1)
		{
			pos = line.GetLength();
			pos -=line.Find("=");
			pos--;
			sscanf(   line.Right(pos) , "%d",&theApp.m_minFilesize); 
			continue;
		}
		// must be an entry
		
		if (theApp.m_ignoreStartPos == 0) // first time?
			theApp.m_ignoreStartPos = data.Find(line);	// save this location so we can start writing new ones when we exit this dialog.

		filename = line.Left(line.Find(","));
		line.TrimLeft(filename);
		line.TrimLeft(",");
		
		ext = line.Left(line.Find(","));
		line.TrimLeft(ext);
		line.TrimLeft(",");

//		size = line.Left(line.Find(","));
//		line.TrimLeft(size);
//		line.TrimLeft(",");
		
		crc = line;
		

		filename.Trim();
		ext.Trim();
//		size.Trim();
		crc.Trim();

		if (crc == "*")
			crc = "0xffffffff";

		sscanf( crc, "%x",&theApp.m_ignoreThese[theApp.m_ignoreTheseCount].crc); 
//		sscanf( size, "%x",&theApp.m_ignoreThese[theApp.m_ignoreTheseCount].size); 
		theApp.m_ignoreThese[theApp.m_ignoreTheseCount].filename = filename;
		theApp.m_ignoreThese[theApp.m_ignoreTheseCount].ext = ext;
		theApp.m_ignoreTheseCount++;

//		theApp.m_ignoreList.AddItem(COLOR_BLACK,filename, ext, size, crc);
	}
}

void CDOSCenterDlg::OnBnClickedApplyignore()
{
	theApp.m_ignoreOn = (((CButton*)GetDlgItem(IDC_APPLYIGNORE))->GetCheck()==1);
}

// generate a full report of files
void CDOSCenterDlg::OnBnClickedMissinglist()
{
	FILE* outFile;
	CString perfect="";
	CString missingFiles="";
	CString missingZipFiles="";
	CString renameOnly="";
	CString crcCollision="";
	CString extraFiles="";
	CString timeTxt;
	CString output="";
	CString txt;
	CSettingsandTools snt;
	CHaveMissDlg hmd;
	int	extraFilesCount=0;
	int crcCCount=0;
	int renameCount=0;
	int perfectCount=0;
	int unknownCount=0;
	int missingCount=0;
	int missingZips=0;
	CdizInfo fiz;	// file_id.diz structure class
	
	dizInfo m_dizInfo;

	CString one="\x001";
	CString two="\x002";
	CString three="\x003";
	//CString m_mySitesDat = "192.168.0.2-DOSGuy";
	CString rootPath="/DOSGuy/";		// we end up getting /DOSGuy/year/filename.zip
	CString tmpPath;
	//CString destPath="C:\\temp\\testDl\\";
	CString fqf="";
	CString size="99999999";	// anything bigger than the actual file seems to work.


	//ZIPdata tempZIPdata;

	time_t rawtime;
	time ( &rawtime );
	timeTxt.Format("Report generated on: %s",ctime (&rawtime));
	timeTxt.Trim();

	for (unsigned int i=0; i<theApp.m_datfileCount; i++)
	{
		// populate the file_id.diz variable list from this filename
		//snt.zipName2Vars(theApp.m_datZipList[i].filename);

		//if (!hmd.yearInSelectedList(snt.m_dizInfo.year))
		//	continue;

		if ( (theApp.m_datZipList[i].status & ~0xff000000) == STATUS_PERFECT)
		{
			perfect+=theApp.m_datZipList[i].filename+"\r\n";
			perfectCount++;
		}
//		if (tempZIPdata.status == STATUS_RENAME_ZIP_ONLY)
//		{
//			renameOnly+=theApp.m_fileData[i].realFilename;
//			renameOnly+="-->";
		//	renameOnly+=tempZIPdata.filename+"\r\n";
//			renameCount++;
//		}
		if ((theApp.m_datZipList[i].status & ~0xff000000) == STATUS_CRC_COLLISION)
		{
			crcCollision+=theApp.m_datZipList[i].filename+"\r\n";
			crcCCount++;
		}	
		if ((theApp.m_datZipList[i].status & ~0xff000000) == STATUS_EXTRAFILES)
		{
			extraFiles+=theApp.m_datZipList[i].filename+"\r\n";
			extraFilesCount++;
			// if really detailed reporting requested
			//generateExtraFileReport(i, extraFiles);
		}	
		if ((theApp.m_datZipList[i].status & ~0xff000000) == STATUS_MISSINGFILES)
		{
			missingFiles+=theApp.m_datZipList[i].filename+"\r\n";
			missingCount++;
	
			if (theApp.m_makeFQFScript) // make fqf
			{
				fiz.zipName2Vars(theApp.m_datZipList[i].filename, true);
				tmpPath=rootPath;
				tmpPath+=m_dizInfo.year;
				tmpPath+="/";
				fqf+="0"+one+"5"+one+two+theApp.m_mySitesDat+one+two+"-"+one+tmpPath+theApp.m_datZipList[i].filename+one+theApp.m_fxpDlPath+theApp.m_datZipList[i].filename+one+size+"\r\n";

			}
		}

		if ((theApp.m_datZipList[i].status & ~0xff000000) == 0)	// totally missing
		{
			missingZipFiles+=theApp.m_datZipList[i].filename+"\r\n";
			missingZips++;
			if (theApp.m_makeFQFScript) // make fqf
			{
				tmpPath=rootPath;
				fiz.zipName2Vars(theApp.m_datZipList[i].filename, true);
				tmpPath+=m_dizInfo.year;
				tmpPath+="/";
				fqf+="0"+one+"5"+one+two+theApp.m_mySitesDat+one+two+"-"+one+tmpPath+theApp.m_datZipList[i].filename+one+theApp.m_fxpDlPath+theApp.m_datZipList[i].filename+one+size+"\r\n";
			}
		}

	}	
	
	output=timeTxt;
	txt.Format("\r\nYou are missing %d of %d known files.\r\n",missingZips,theApp.m_datfileCount);
	output+=txt;
	txt.Format("You have %d perfect zips out of %d known files.\r\n",perfectCount,theApp.m_datfileCount);
	output+=txt;
	txt.Format(".zip filename is incorrect: %d\r\n",renameCount);
	output+=txt;
	txt.Format("CRC collisions: %d\r\n",crcCCount);
	output+=txt;
	txt.Format(".zip has extra files: %d\r\n",extraFilesCount);
	output+=txt;
	txt.Format(".zip is missing files: %d\r\n",missingCount);
	output+=txt;

	
	if (theApp.m_detailedReport)
	{
		output +="Detailed Report\r\n";
		output +="-----------------------------------\r\n";
		output +="--        Missing ZIP Files      --\r\n";
		output +="-----------------------------------\r\n";
		output+=missingZipFiles;
		
		output +="-----------------------------------\r\n";
		output +="--        Rename these           --\r\n";
		output +="-----------------------------------\r\n";
		output +="use DOSCenter to rename zips that display as BROWN in the left hand window\r\n";
		output +=renameOnly;
		
		output +="-----------------------------------\r\n";
		output +="--        CRC collisions         --\r\n";
		output +="-----------------------------------\r\n";
		output +=crcCollision;

		output +="-----------------------------------\r\n";
		output +="--        ZIP has extra files    --\r\n";
		output +="use DOSCenter to examine these zips to know which files are extra\r\n";
		output +="-----------------------------------\r\n";
		output +=extraFiles;
		
		// display extra/missing files here too
		output +="-----------------------------------\r\n";
		output +="--        ZIP is missing files   --\r\n";
		output +="use DOSCenter to examine these zips to know which files are missing\r\n";
		output +="-----------------------------------\r\n";
		output +=missingFiles;
		
		if (theApp.m_reportPerfects)
		{
			output +="-----------------------------------\r\n";
			output +="--        Perfect Files          --\r\n";
			output +="-----------------------------------\r\n";
			output+=perfect;
		}

	}

	if (1)	// checkbox...
	{
		output +="-----------------------------------\r\n";
		output +="--        Scan Results           --\r\n";
		output +="-----------------------------------\r\n";

		// read the results right off the screen
		int nIndex = 0;
		CString zipfilename;
		CString tgtFilename;
		while (1)
		{
			// get destination filename - make it just a variation of the filename we've selected
			//nIndex = theApp.m_leftSideList.GetNextItem(0nIndex, LVNI_SELECTED);
			
			zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
			tgtFilename = theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL);
			if (tgtFilename.IsEmpty())
				break;
			// trim off any folder
			zipfilename = extractFilenameWOPath(zipfilename);
			output+=zipfilename+"| "+tgtFilename+"\r\n";
			nIndex++;
		}
	}


	// if generating a flashFXP queue, this is the command line to run:
	// FLASHFXP.EXE -c2 -go DCupdate.fqf
	// contents of DCupdate.fqf:
	// <file type> [1] <direction> [1] <source ftp://>                     [1] <target ftp://> [1] <source file> [1] <target file> [1] <file size> [CR/LF]
	//       0     [1]       5     [1][2]40900.6690024537[1]208.42.141.191 [1][2]-             [1]/DOSGuy/year/filename.zip[1]destination path+filename[1]filesize[CR/LF]
	//
	// need all missing, missing files added to the fqf file.  missingZipFiles, missingFiles
	//


	outFile = fopen("c:\\DCreport.txt","wb");
	if ( outFile != NULL )
		fwrite(output, sizeof( char ), output.GetLength(), outFile );
	
	if ( outFile != NULL )
	{
		fclose(outFile);
		outFile=NULL;
	}
	AfxMessageBox("File c:\\DCreport.txt created.", MB_ICONINFORMATION, 0);

	if (theApp.m_makeFQFScript) // fqf
	{
		outFile = fopen("c:\\DCDownload.fqf","wb");
		if ( outFile != NULL )
			fwrite(fqf, sizeof( char ), fqf.GetLength(), outFile );
		
		if ( outFile != NULL )
		{
			fclose(outFile);
			outFile=NULL;
		}
		AfxMessageBox("File c:\\DCDownload.fqf created too.", MB_ICONINFORMATION, 0);
	}

	
}


// right side, zip details, user wants to delete selected files out of the zip itself.
void CDOSCenterDlg::deleteFileInZip()
{
	CString logData;

	int nIndex=-1;
	int	m_nFileCount;
	UZ_FileInfo info;
	ZIPMERGE* zipMerge;
	zipMerge = new _ZIPMERGE[1];	
	CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
	CString tmp, ext;
	CFileStuff files; 

	CProgressDlg progDlg;

		// count number of items in list-popup verify message.
	int count=0;
	while (1) 
		{
			nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);
			if (nIndex == -1)
				break;
			count++;
		}
	tmp.Format("Delete %d file(s)?", count);
	int choice = AfxMessageBox(tmp, MB_ICONWARNING | MB_YESNO, 0);
		if ( choice == IDNO )
			return;



	// get destination filename - make it just a variation of the 1st filename in the selected pool
	nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
	zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
	targetZipName = zipfilename;
	// trim off any folder
	targetZipName = extractFilenameWOPath(targetZipName);
	targetZipName.Insert(0,"WIP");

	progDlg.Init(PROG_MODE_TIMER, 1000, "Unzipping file...");

	// put all files inside this zip into the array
	m_uz.OpenZip(m_SourcePath+zipfilename);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();

	for (int i=0; i<m_nFileCount; i++)	// for each file in the zip...
		{
			filename = info.szFileName;
			nIndex = -1;
			while (1) // scan through all selected files and if they are in our delete list, don't add them to the unzip map.
			{
				nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;

				tmp = theApp.m_zipDetailsList.GetItemText(nIndex,FILENAMECOL);
				tmp +="."+theApp.m_zipDetailsList.GetItemText(nIndex,2);
				//if there's no extension trim it
				tmp.TrimRight(".");
				if (filename == tmp)
				{
					filename="";
					break;
				}
			}
			if (filename.GetLength() > 0)	// made it throughthe selection criteria?
				zipMerge[0].mymap[filename].name = filename;
			m_uz.GotoNextFile();
			m_uz.GetFileInfo(info);
        }
	

	m_uz.CloseZip();


	// create a temporary folder
	CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);
	if (!m_uz.Unzip(m_SourcePath+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))
		{
//			logData+="\r\n**Error unzipping file:"+zipfilename;
			AfxMessageBox("Error unzipping file! "+zipfilename, MB_ICONEXCLAMATION, 0);
			m_uz.CloseZip();
			progDlg.UpdateText("Cleaning up...");
			// delete temporary work space
			if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
				AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
			progDlg.DestroyWindow();
			delete[] zipMerge;
			return;
		}
	m_uz.CloseZip();



	


	progDlg.UpdateText("Creating new zip:"+targetZipName);
	
	
	
	m_zip.OpenZip(m_SourcePath+"\\"+targetZipName, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"); // create a fresh zip file

	zipMerge[0].it = zipMerge[0].mymap.begin();
			while( zipMerge[0].it != zipMerge[0].mymap.end() ) 
			{
				filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+zipMerge[0].it->first;
				m_zip.AddFileToZip(filename);
				zipMerge[0].it++;
			}

	m_zip.CloseZip();


	// delete the original file, move the new one back in.
	
	progDlg.UpdateText("Cleaning up...");
	
	remove(m_SourcePath+zipfilename);
	MoveFile(m_SourcePath+targetZipName, m_SourcePath+zipfilename);

	// delete temporary work space
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);


//	theApp.m_leftSideList.AddItem(COLOR_BLACK, targetZipName, "", "", "", "", "");	// column 0 is color, zipfilename, new filename, score, match, missing, unknown
//	m_zipFiles++;	// next file please
//	m_zipCount++;
	OnNMDblclkZipFileList(0, 0);
	delete[] zipMerge;
	progDlg.DestroyWindow();
	return;
}

// right side, zip details, user wants to extract the selected files and dump them into a zip of the target (suggested) filename
void CDOSCenterDlg::zip2NewFile()
{
	CString logData;

	int nIndex=-1;
	int	m_nFileCount;
	UZ_FileInfo info;
	ZIPMERGE* zipMerge;
	zipMerge = new _ZIPMERGE[1];	
	CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
	CString tmp, ext;
	CFileStuff files; 

	CProgressDlg progDlg;
	CNewFilenameDlg dlg;

	// get destination filename - make it just a variation of the 1st filename in the selected pool
	nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
	zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
//	targetZipName = zipfilename;
//	// trim off any folder
//	targetZipName = extractFilenameWOPath(targetZipName);
//	targetZipName.Insert(0,"WIP");

	// pop up target filename here
	CString source = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
	CString subPath = source.Left(source.ReverseFind('\\'));
	if (subPath.GetLength() != 0)
		subPath+="\\";
	dlg.m_txt = source;
	if ( (theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "") && (theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "no good matches") 
	  && (theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL) != "perfect!")  )
		dlg.m_txt = subPath+theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL);
			
	dlg.DoModal();
	if (dlg.m_ok == 0)
		return;
			
	targetZipName = dlg.m_txt;

	progDlg.Init(PROG_MODE_TIMER, 1000, "Unzipping file...");

	// put all files inside this zip into the array
	m_uz.OpenZip(m_SourcePath+zipfilename);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();

	for (int i=0; i<m_nFileCount; i++)	// for each file in the zip...
		{
			filename = info.szFileName;
			nIndex = -1;
			while (1) // scan through all selected files and if they are in our delete list, don't add them to the unzip map.
			{
				nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;

				tmp = theApp.m_zipDetailsList.GetItemText(nIndex,FILENAMECOL);
				tmp +="."+theApp.m_zipDetailsList.GetItemText(nIndex,2);
				
				//if there's no extension trim it
				tmp.TrimRight(".");
				
				if (filename == tmp)
					zipMerge[0].mymap[filename].name = filename;
			}
			m_uz.GotoNextFile();
			m_uz.GetFileInfo(info);
        }

	m_uz.CloseZip();


	// create a temporary folder
	CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);
	if (!m_uz.Unzip(m_SourcePath+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))
		{
//			logData+="\r\n**Error unzipping file:"+zipfilename;
			AfxMessageBox("Error unzipping file! "+zipfilename, MB_ICONEXCLAMATION, 0);
			m_uz.CloseZip();
			progDlg.UpdateText("Cleaning up...");
			// delete temporary work space
			if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
				AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
			progDlg.DestroyWindow();
			delete[] zipMerge;
			return;
		}
	m_uz.CloseZip();



	

	// create a new zip
	progDlg.UpdateText("Creating new zip:"+targetZipName);
	m_zip.OpenZip(m_SourcePath+"\\"+targetZipName, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"); // create a fresh zip file

	zipMerge[0].it = zipMerge[0].mymap.begin();
			while( zipMerge[0].it != zipMerge[0].mymap.end() ) 
			{
				filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+zipMerge[0].it->first;
				m_zip.AddFileToZip(filename);
				zipMerge[0].it++;
			}

	m_zip.CloseZip();


	// delete the original file, move the new one back in.
	
	progDlg.UpdateText("Cleaning up...");
	
//	remove(m_SourcePath+zipfilename);
//	MoveFile(m_SourcePath+targetZipName, m_SourcePath+zipfilename);

	// delete temporary work space
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);


	theApp.m_leftSideList.AddItem(COLOR_BLACK, targetZipName, "", "", "", "", "");	// column 0 is color, zipfilename, new filename, score, match, missing, unknown
//	m_zipFiles++;	// next file please
//	m_zipCount++;
	OnNMDblclkZipFileList(0, 0);
	delete[] zipMerge;
	progDlg.DestroyWindow();
	return;
}


// right side, zip details, user wants to rename a selected file in the zip itself.
void CDOSCenterDlg::renameFileInZip()
{
	CString dest;
	int nIndex=-1;
	int	m_nFileCount;
	UZ_FileInfo info;
	ZIPMERGE* zipMerge;
	zipMerge = new _ZIPMERGE[1];	
	CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
	CString tmp, ext;
	CFileStuff files; 

//	CProgressDlg progDlg;
	CNewFilenameDlg dlg;

	// get destination filename - make it just a variation of the 1st filename in the selected pool
	nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
	zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
	targetZipName = zipfilename;
	// trim off any folder
	targetZipName = extractFilenameWOPath(targetZipName);
	targetZipName.Insert(0,"WIP");

//	progDlg.Init(PROG_MODE_TIMER, 1000, "Unzipping file...");

	// create a temporary folder
	CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);
	if (!m_uz.Unzip(m_SourcePath+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))
		{
//			logData+="\r\n**Error unzipping file:"+zipfilename;
			AfxMessageBox("Error unzipping file! "+zipfilename, MB_ICONEXCLAMATION, 0);
			m_uz.CloseZip();
			//progDlg.UpdateText("Cleaning up...");
			// delete temporary work space
			if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
				AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
		//	progDlg.DestroyWindow();
			delete[] zipMerge;
			return;
		}
	m_uz.CloseZip();







	// put all files inside this zip into the array
	m_uz.OpenZip(m_SourcePath+zipfilename);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();

	for (int i=0; i<m_nFileCount; i++)	// for each file in the zip...
		{
			filename = info.szFileName;
			nIndex = -1;
			while (1) // scan through all selected files and if they are in our delete list, don't add them to the unzip map.
			{
				nIndex = theApp.m_zipDetailsList.GetNextItem(nIndex, LVNI_SELECTED);
				if (nIndex == -1)
					break;

				tmp = theApp.m_zipDetailsList.GetItemText(nIndex,FILENAMECOL);
				tmp +="."+theApp.m_zipDetailsList.GetItemText(nIndex,2);
				if (filename == tmp)
				{
					// pop up the rename dialog
					dlg.m_txt = filename;
					dlg.DoModal();
					if (dlg.m_ok == 1)
					{
						dest = dlg.m_txt;
						dest.Replace("\t"," ");
						dest.Trim();
						if (!MoveFile(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+filename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+dest))
						{
							AfxMessageBox("Error renaming file! "+theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+filename, MB_ICONEXCLAMATION, 0);
							// what kind of error recovery do we do here?
						}
					}	
					else	// user abort
					{
						//filename = dest;
						m_uz.CloseZip();
						// delete temporary work space
						if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
							AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);

						OnNMDblclkZipFileList(0, 0); // refresh (not really needed)
						delete[] zipMerge;
						return;
					}
				}
			}
			// add filename or new filename into array
			zipMerge[0].mymap[filename].name = filename;
			m_uz.GotoNextFile();
			m_uz.GetFileInfo(info);
        }
	m_uz.CloseZip();



	

	// zip it all back up.
//	progDlg.UpdateText("Creating new zip:"+targetZipName);
	
	m_zip.OpenZip(m_SourcePath+"\\"+targetZipName, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"); // create a fresh zip file

	zipMerge[0].it = zipMerge[0].mymap.begin();
			while( zipMerge[0].it != zipMerge[0].mymap.end() ) 
			{
				filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+zipMerge[0].it->first;
				m_zip.AddFileToZip(filename);
				zipMerge[0].it++;
			}

	m_zip.CloseZip();



	// delete the original file, move the new one back in.
//	progDlg.UpdateText("Cleaning up...");
	
	remove(m_SourcePath+zipfilename);
	MoveFile(m_SourcePath+targetZipName, m_SourcePath+zipfilename);

	// delete temporary work space
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);


	OnNMDblclkZipFileList(0, 0);
	delete[] zipMerge;
//	progDlg.DestroyWindow();
	return;
}

// move all files in a zip file up 1 level. 
void CDOSCenterDlg::unNestZipFile()
{
	CString dest;
	int nIndex=-1;
	int	m_nFileCount;
	UZ_FileInfo info;
	ZIPMERGE* zipMerge;
	zipMerge = new _ZIPMERGE[1];	
	CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
	CString tmp, ext;
	CFileStuff files; 

	CProgressDlg progDlg;
	CNewFilenameDlg dlg;
	progDlg.Init(PROG_MODE_TIMER, 1000, "Unzipping file...");
	
	// get destination filename - make it just a variation of the 1st filename in the selected pool
	nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
	zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
	targetZipName = zipfilename;
	// trim off any folder
	targetZipName = extractFilenameWOPath(targetZipName);
	targetZipName.Insert(0,"WIP");



	CString zipDir = findRootZipFolder(m_SourcePath+zipfilename);

	if (zipDir.GetLength() == 0)
	{
		AfxMessageBox("Not all files are buried", MB_ICONWARNING, 0);
		progDlg.DestroyWindow();
		delete[] zipMerge;
		return;
	}


	



	// create a temporary folder
	CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);
	if (!m_uz.Unzip(m_SourcePath+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))
		{
			AfxMessageBox("Error unzipping file! "+zipfilename, MB_ICONEXCLAMATION, 0);
			m_uz.CloseZip();
			// delete temporary work space
			if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
				AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
			delete[] zipMerge;
			progDlg.DestroyWindow();
			return;
		}
	m_uz.CloseZip();


	// put all files inside this zip into the array
	m_uz.OpenZip(m_SourcePath+zipfilename);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();

	for (int i=0; i<m_nFileCount; i++)	// for each file in the zip...
		{
			filename = info.szFileName;
			filename = filename.Right(filename.GetLength() - zipDir.GetLength());
			// add filename or new filename into array
			if (filename.GetLength() > 0)
				zipMerge[0].mymap[filename].name = filename;
			m_uz.GotoNextFile();
			m_uz.GetFileInfo(info);
        }
	m_uz.CloseZip();



	// get the name of the root folder that we're about to elimate

	// zip it all back up.
	progDlg.UpdateText("Creating new zip:"+targetZipName);
	
	m_zip.OpenZip(m_SourcePath+"\\"+targetZipName, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+zipDir); // create a fresh zip file

	zipMerge[0].it = zipMerge[0].mymap.begin();
			while( zipMerge[0].it != zipMerge[0].mymap.end() ) 
			{
				filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+zipDir+zipMerge[0].it->first;
				m_zip.AddFileToZip(filename);
				zipMerge[0].it++;
			}

	m_zip.CloseZip();



	// delete the original file, move the new one back in.
	progDlg.UpdateText("Cleaning up...");
	
	remove(m_SourcePath+zipfilename);
	MoveFile(m_SourcePath+targetZipName, m_SourcePath+zipfilename);

	// delete temporary work space
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);


	OnNMDblclkZipFileList(0, 0);
	delete[] zipMerge;
	progDlg.DestroyWindow();
	return;
}

// returns a CString of the folder that all files are contained in.
// ideally, this would return "\" or just a null string, but a LOT of zip files now are showing up as:
// \game name\files or
// \game name\game name\files
CString CDOSCenterDlg::findRootZipFolder(CString zipfilename)
{
	CString zipDir="";
	CString tmp;
	CString folder;
	int	m_nFileCount;
	UZ_FileInfo info;
	// grab the zip and see if each file is inside a folder.
	m_uz.OpenZip(zipfilename);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();

	// get the first file's folder
	folder = info.szFileName;
	if (folder.Find('\\') == -1)	
		return zipDir;	// bail if we've ever found no folders
	
	// get the name of the folder
	folder = folder.Left(folder.Find('\\')+1);
	zipDir = folder;
	for (int i=0; i<m_nFileCount; i++)	// now examine each file to see if it's in the same folder.
	{
		m_uz.GotoNextFile();
		m_uz.GetFileInfo(info);
		tmp = info.szFileName;
		if (tmp.Left(folder.GetLength()) == folder)
			continue;
		else
			{
				zipDir="";
				break;
			}
		
	} // for

	m_zip.CloseZip();
	return zipDir;
}


// drag a new file into a zip file.
// this is exactly backwards.  the setting for the left side window on the GUI editor says "accept files=true" and it doesn't come here when the user drags a file to that side.
// on the other hand, the right side window says "accept files=false" and that gets called here when the file is dragged.  lovely.  whatever, it works.
LRESULT  CDOSCenterDlg::OnDropFiles(WPARAM wParam,LPARAM lParam)
{
	char	szDroppedFile[MAX_PATH];
	HDROP	hDrop ;
	int nFiles=0;
	CString csString;
	int	nIndex=-1;
	CString dest;

	int	m_nFileCount;
	UZ_FileInfo info;
	ZIPMERGE* zipMerge;
	zipMerge = new _ZIPMERGE[1];	
	CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
	CString tmp, ext;
	CFileStuff files; 


	// do we have multiple files selected on the left?  can't handle that either.
	// ok, we could do multiple zips on the left, but let's not for now.
	while (1)
	{
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		nFiles++;		
	}

	if (nFiles !=1)
		return 0;

	// get destination filename - make it just a variation of the filename we've selected
	nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
	zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
	targetZipName = zipfilename;
	// trim off any folder
	targetZipName = extractFilenameWOPath(targetZipName);
	targetZipName.Insert(0,"WIP");

	// create a temporary folder
	CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);
	if (!m_uz.Unzip(m_SourcePath+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))
		{
//			logData+="\r\n**Error unzipping file:"+zipfilename;
			AfxMessageBox("Error unzipping file! "+zipfilename, MB_ICONEXCLAMATION, 0);
			m_uz.CloseZip();
			//progDlg.UpdateText("Cleaning up...");
			// delete temporary work space
			if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
				AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
		//	progDlg.DestroyWindow();
			delete[] zipMerge;
			return 0;
		}
	m_uz.CloseZip();


	// put all files inside this zip into the array
	m_uz.OpenZip(m_SourcePath+zipfilename);
	m_uz.GotoFirstFile();
	m_uz.GetFileInfo(info);
	m_nFileCount = m_uz.GetFileCount();
	for (int i=0; i<m_nFileCount; i++)	// for each file in the zip...
		{
			// add filename or new filename into array
			filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+info.szFileName;
			zipMerge[0].mymap[filename].name = filename;
			m_uz.GotoNextFile();
			m_uz.GetFileInfo(info);
        }
	m_uz.CloseZip();

	// now add the extra files dragged in.
	hDrop = (HDROP)wParam;
	UpdateData();

	nFiles = DragQueryFile(hDrop,		// Struture Identifier
				  -1,			// -1 to Drop more than one file
				  szDroppedFile,// Droped File Name
				  MAX_PATH);	// Max char

	// for each file, add the path into our zip array.
	for(int i=0;i<nFiles;i++)
		{
			DragQueryFile(hDrop,i,szDroppedFile,MAX_PATH);
			filename = szDroppedFile;
			zipMerge[0].mymap[filename].name = filename;
		}





	// zip it all back up.
//	progDlg.UpdateText("Creating new zip:"+targetZipName);
	
	m_zip.OpenZip(m_SourcePath+"\\"+targetZipName, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"); // create a fresh zip file

	zipMerge[0].it = zipMerge[0].mymap.begin();
			while( zipMerge[0].it != zipMerge[0].mymap.end() ) 
			{
				filename = zipMerge[0].it->first;
				m_zip.AddFileToZip(filename, true);
				zipMerge[0].it++;
			}

	m_zip.CloseZip();



	// delete the original file, move the new one back in.
//	progDlg.UpdateText("Cleaning up...");
	
	remove(m_SourcePath+zipfilename);
	MoveFile(m_SourcePath+targetZipName, m_SourcePath+zipfilename);

	// delete temporary work space
	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);


	OnNMDblclkZipFileList(0, 0);
	delete[] zipMerge;
//	progDlg.DestroyWindow();
	return 0;

}


// scan every file and look for the latest year data
void CDOSCenterDlg::doYearScan()
{
	CString csString;
	int	nIndex=-1;
	CString dest;
	int	latestYear = 0;
	int tmp;
	FILE* srcFile;	// file from DOS collection

	int	m_nFileCount;
	UZ_FileInfo info;
//	ZIPMERGE* zipMerge;
//	zipMerge = new _ZIPMERGE[1];	
	CString zipfilename;
	CString filename;	// rom filename
	CString targetZipName;
//	CString tmp, ext;
	CFileStuff files; 
	CString yearTxt, meh;


	while (1)
	{
		// get destination filename - make it just a variation of the filename we've selected
		nIndex = theApp.m_leftSideList.GetNextItem(nIndex, LVNI_SELECTED);
		if (nIndex == -1)
			break;
		
		zipfilename = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);
		targetZipName = zipfilename;
		// trim off any folder
		targetZipName = extractFilenameWOPath(targetZipName);
		targetZipName.Insert(0,"WIP");

		// create a temporary folder
		CreateDirectory(_T(theApp.m_tmpWorkingFolder+"\\DOSCenterUz"), NULL);
		if (!m_uz.Unzip(m_SourcePath+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz"))
			{
	//			logData+="\r\n**Error unzipping file:"+zipfilename;
				AfxMessageBox("Error unzipping file! "+zipfilename, MB_ICONEXCLAMATION, 0);
				m_uz.CloseZip();
				//progDlg.UpdateText("Cleaning up...");
				// delete temporary work space
				if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
					AfxMessageBox("Warning, unable to clean up temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
			//	progDlg.DestroyWindow();
	//			delete[] zipMerge;
				return;
			}
		m_uz.CloseZip();



		
		m_uz.OpenZip(m_SourcePath+zipfilename);
		m_uz.GotoFirstFile();
		m_nFileCount = m_uz.GetFileCount();
		for (int i=0; i<m_nFileCount; i++)	// for each file in the zip...
			{
				m_uz.GetFileInfo(info);
				unsigned int size = info.dwUncompressedSize + (16 - (info.dwUncompressedSize & 0xf));
				char* srcBuffer = new char[size];
				memset(srcBuffer,0,size);

				// read the file in
				filename = theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+info.szFileName;
				srcFile = fopen(filename,"rb");

				if (srcFile != NULL)
					fread(srcBuffer,info.dwUncompressedSize,1 ,srcFile);

				// close file
				if (srcFile != NULL)
					fclose(srcFile);	

				// scan the contents for anything that looks like a year.
				for (unsigned int bc=0; bc<size; bc++)
				{
					if ( srcBuffer[bc] == '1')
					{
						// start the comparison.
						if (srcBuffer[bc+1] == '9')
						{
							if ( (srcBuffer[bc+2] == '9') || (srcBuffer[bc+2] == '8') )
							{
								tmp = ( (srcBuffer[bc] << 24) + (srcBuffer[bc+1] << 16) + (srcBuffer[bc+2] << 8) + srcBuffer[bc+3] );
									if (tmp > latestYear)
										latestYear = tmp;	// value is now ASCII hex.  
							}
								
						}


					}
				}
			m_uz.GotoNextFile();
			delete []srcBuffer;

			}
		m_uz.CloseZip();

		// clean up working folder
		if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"))
			AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);

		if (latestYear > 0)
		{
			
			meh ="_(";
			yearTxt.Format("%c",(latestYear >> 24));
			meh +=yearTxt;
			yearTxt.Format("%c",(latestYear >> 16));
			meh +=yearTxt;
			yearTxt.Format("%c",(latestYear >> 8));
			meh +=yearTxt;
			yearTxt.Format("%c",latestYear);
			meh +=yearTxt;
			meh +=")";
			
			zipfilename.MakeLower();
			zipfilename = zipfilename.Left(zipfilename.Find(".zip"));
			zipfilename +=meh+".zip";
			theApp.m_leftSideList.SetItemText(nIndex,NEWFILENAMECOL,zipfilename);
		}
	
	} // while loop
	

}
void CDOSCenterDlg::OnBnClickedDatzipflip()
{
	m_datview = !m_datview;
	theApp.m_zipDetailsList.DeleteAllItems();	// clean up whatever was on the right side
	if (m_datview)
	{
		CString sourceName;
		int	nIndex = theApp.m_leftSideList.GetNextItem(-1, LVNI_SELECTED);
		sourceName = theApp.m_leftSideList.GetItemText(nIndex,NEWFILENAMECOL);
		// get first filename if 2nd filename is "perfect!"  
		if ( (sourceName == "perfect!") || (sourceName == "no good matches") )
			sourceName = theApp.m_leftSideList.GetItemText(nIndex,FILENAMECOL);

		if ((m_datview) && (!theApp.m_datParsed))
			populateDATFileDataView();	// if we have not put all the data into the view, do so now. (only needs to be done once)

		theApp.m_leftSideList.ShowWindow(0);
		theApp.m_leftSideDATList.ShowWindow(1);
		((CButton*)GetDlgItem(IDC_DATZIPFLIP))->SetWindowText("Zip view");

		
		// find the selected filename in this new view
		// highlight+goto our matched item. 
		for (unsigned int i=0; i<theApp.m_datfileCount; i++)
		{
			theApp.m_leftSideDATList.SetItemState(i, 0, LVIS_SELECTED); // unselect each
			if (theApp.m_leftSideDATList.GetItemText(i,1) == sourceName)
				nIndex=i;
		}	
			if (nIndex != -1)
			{
				theApp.m_leftSideDATList.EnsureVisible(nIndex, 1);
				theApp.m_leftSideDATList.SetItemState(nIndex, LVIS_SELECTED, LVIS_SELECTED);
				OnNMDblclkDatFileList(NULL,NULL);
			}
	}
	else
	{
		theApp.m_leftSideList.ShowWindow(1);
		theApp.m_leftSideDATList.ShowWindow(0);
		((CButton*)GetDlgItem(IDC_DATZIPFLIP))->SetWindowText("DAT view");
	}
}
void CDOSCenterDlg::populateDATFileDataView()
{
	CString zipName;
	CString romCount;
	CString color;
	// if we are sitting on a zip file when this button is pressed, see if we can find it in the dat view

	theApp.m_leftSideDATList.DeleteAllItems();	// clean up the left side list

	theApp.m_datZipListit = theApp.m_datZipList.begin();
//	int count=-1;
//	nIndex=-1;
	while (theApp.m_datZipListit != theApp.m_datZipList.end())
	{
		zipName = theApp.m_datZipListit->second.filename;	// 2nd element is the 2nd thing stored in this map. weird stuff.
		romCount.Format("%d",theApp.m_datZipListit->second.fileCount);
		color=COLOR_BLACK;
		if ((theApp.m_datZipListit->second.status & TZIPPED) == TZIPPED)
			color=COLOR_PBROWN;
		if (zipName.GetLength() > 0)
		{
			theApp.m_leftSideDATList.AddItem(color, zipName, romCount);	
//			count++;
		}
		theApp.m_datZipListit++;
	}
	theApp.m_datParsed = true;
	theApp.m_leftSideDATList.Sort(1,true);	// sort by filename
}

// user has 2x clicked on the dat viewer window - display the files inside this dat entry
void CDOSCenterDlg::OnNMDblclkDatFileList(NMHDR *pNMHDR, LRESULT *pResult)
{
	CString zipFilename;
	CString filename, ext, date, size, crc;
	int	nIndex;
	int romCount;
	WORD dosDate;
	WORD dosTime;
	ROMdata tempROMdata;	// temporary storage for the lookup
	//ZIPdata tempZIPdata;		// temporary storeage for the zip file (from the .dat) the data came from
	

	// no selection?  abort
	nIndex = theApp.m_leftSideDATList.GetNextItem(-1, LVNI_SELECTED);
	if (nIndex == -1)
		return;
	
	// get the name of the zip file that the scanner is suggesting we use.
	zipFilename = theApp.m_leftSideDATList.GetItemText(nIndex,FILENAMECOL);	// dat filename

	// scan through the cmap to find this particular entry
	theApp.m_datZipListit = theApp.m_datZipList.begin();
	while (theApp.m_datZipListit != theApp.m_datZipList.end())
	{
		if (zipFilename == theApp.m_datZipListit->second.filename)
			break;
		theApp.m_datZipListit++;
	}
	// update the zip contents list
	theApp.m_zipDetailsList.DeleteAllItems();

	romCount = theApp.m_datZipListit->second.fileCount;
	for (int i=0; i<romCount; i++)
	{
		filename = theApp.m_datZipListit->second.ROMsMap[i].name;
		ext = extractExtension(filename);
		crc.Format("%x",theApp.m_datZipListit->second.ROMsMap[i].crc);
		size.Format("%d",theApp.m_datZipListit->second.ROMsMap[i].size);
		int q = theApp.m_datZipListit->second.ROMsMap[i].date;
		dosDate = (WORD)(theApp.m_datZipListit->second.ROMsMap[i].date >> 16);
		dosTime = (WORD)theApp.m_datZipListit->second.ROMsMap[i].date & 0xffff;
		CTime time(dosDate, dosTime);
		date =time.Format( "%Y/%m/%d %H:%M:%S" );

		theApp.m_zipDetailsList.AddItem(COLOR_BLACK,filename, ext, size, date, crc);	
	}
}
void CDOSCenterDlg::CopyToClipboard(const char* stringbuffer)
{
   //try to open clipboard first
   if (!OpenClipboard())
   {
      return;
   }
  
   //clear clipboard
   EmptyClipboard();
 
   HGLOBAL clipbuffer;
   char * buffer;
   
   //alloc enough mem for the string;
   //must be GMEM_DDESHARE to work with the clipboard
   clipbuffer = GlobalAlloc(GMEM_DDESHARE, strlen(stringbuffer)+1);
   buffer = (char*)GlobalLock(clipbuffer);
   strcpy(buffer, LPCSTR(stringbuffer));
   GlobalUnlock(clipbuffer);
   
   //fill the clipboard with data
   //CF_TEXT indicates that the buffer is a text-string
   ::SetClipboardData(CF_TEXT,clipbuffer);
   //close clipboard as we don't need it anymore
   CloseClipboard();
}

/* fix a zip
0) scan; if score=100 return, else: - done on entry
1) locate entry from .dat file - passed in
2) build Cmap of all files from dat, including name, path, timestamp, crc, flags
3) unzip matching CRCs from target zip, mark off files in cmap as we progress
4) unzip matching CRCs from update pack(s), mark off files in cmap as we progress
-) do a "deep scan" search to locate CRC files from other zips?
5) update case, pathnames, timestamps on all files in temp folder
6) build new file_id.diz, if not present
7) all files present?  no, clean up and abort.
8) rezip with maximum compression
9) move file back to source folder, delete old file (or rename it to be safe)
10) re-scan new file.  should now be "perfect!"
*/
// entry: full path+filename of the zip we want to fix (since it may not be the same as the .dat file); assumes scanning has already been done.
// zipPosPtr = index into .dat file of the entry we're trying to make the target zip file become.
//  exit: returns true if the zip is now fixed, false if not. 
bool CDOSCenterDlg::fixazip(CString zipName, int zipPosPtr)
{
	ZIPdata tempZIPdata;		// temporary storage for the zip file (from the .dat) the data came from
	CString scanSuggest, zipfilename, romfilename;
	int numRoms;				// count of files (roms) inside the zip of the entry in the .dat file
	CString tmp;
	CFileStuff files; 

	// 2) build Cmap of all files from dat, including name, path, timestamp, crc, flags
	numRoms = theApp.m_datZipList[zipPosPtr].fileCount;
	if (numRoms < m_scannedZipFileCount)
	{
		CString tmp="Warning, there are unknown files in this zip.\r\nThis operation will delete those files out of your target zip, and you will lose them.  Are you ok with that?";
		int choice = AfxMessageBox(tmp, MB_ICONWARNING | MB_YESNO, 0);
		if ( choice == IDNO )
			return false;
	}

	for (int i=0; i< numRoms; i++)
	{
		tempZIPdata.ROMsMap[i].name = theApp.m_datZipList[zipPosPtr].ROMsMap[i].name;
		tempZIPdata.ROMsMap[i].crc = theApp.m_datZipList[zipPosPtr].ROMsMap[i].crc;
		tempZIPdata.ROMsMap[i].date = theApp.m_datZipList[zipPosPtr].ROMsMap[i].date;
		tempZIPdata.status = 0;
	}
	
	// create a temporary folder if it doesn't already exist
	CString tmpFolder = theApp.m_tmpWorkingFolder+"\\DOSCenterUz"; 
	CreateDirectory(_T(tmpFolder), NULL);

	if (!files.DeleteDirectory(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\")) // then delete it so it is clean
	{
		AfxMessageBox("Warning, unable to clean up DOSCenter temporary working folder.\r\n"+theApp.m_tmpWorkingFolder , MB_ICONWARNING, 0);
		return false;
	}
	
	// create a temporary folder
	tmpFolder = theApp.m_tmpWorkingFolder+"\\DOSCenterUz"; 
	CreateDirectory(_T(tmpFolder), NULL);
	
	// 3) unzip matching CRCs from target zip, mark off files in cmap as we progress
//fixme - this is going to be very slow as the source zip is opened+closed every time...beter to pass in a map of files that we're looking for.
	for (int i=0; i< numRoms; i++) //-outer loop= # of ROMS from the dat we're looking for.
	{
		if (tempZIPdata.ROMsMap[i].status == 1)	// if we've already found this ROM, skipit
			continue;

		if (unzipAndFixAROMFromAZip(m_SourcePath+zipName, tempZIPdata.ROMsMap[i].name, tmpFolder, tempZIPdata.ROMsMap[i].crc, tempZIPdata.ROMsMap[i].date) == true)
			tempZIPdata.ROMsMap[i].status = 1;	// mark this rom as found
				// do other stuff
	}

	// 4) unzip matching CRCs from update pack(s), mark off files in cmap as we progress
	for (int i=0; i< numRoms; i++) //-outer loop= # of ROMS from the dat we're looking for.
	{
		if (tempZIPdata.ROMsMap[i].status == 1)	// if we've already found this ROM, skipit
			continue;
		//if (getROMFromUpdatePacks(tempZIPdata.ROMsMap[i].name, tmpFolder, tempZIPdata.ROMsMap[i].crc, tempZIPdata.ROMsMap[i].date) == true)
		//	tempZIPdata.ROMsMap[i].status = 1;	// mark this rom as found

		if (unzipAndFixAROMFromAZip(m_updatePackSourcePath+"\\TDCR6updatePack.zip", tempZIPdata.ROMsMap[i].name, tmpFolder, tempZIPdata.ROMsMap[i].crc, tempZIPdata.ROMsMap[i].date) == true)
			tempZIPdata.ROMsMap[i].status = 1;	// mark this rom as found
				// do other stuff
	}
	
	//-) do a "deep scan" search to locate CRC files from other zips?  
	// lookup CRC in other zips in the dat, if we can find it, we re-do step #3 with a different zipname.


	// we made it!
	// 5) update case, pathnames, timestamps on all files in temp folder
	// this is now done at unzip time

	// 6) -- build new file_id.diz, if we don't already have a good one. (from crc matching) we can also distribute file_id.diz in upgradepacks.zip
	for (int i=0; i< numRoms; i++) //# of ROMS from the dat we're looking for.
	{
		if ( (tempZIPdata.ROMsMap[i].status != 1) && ( (tempZIPdata.ROMsMap[i].name == "file_id.diz") || (tempZIPdata.ROMsMap[i].name == "FILE_ID.DIZ")) )
		{
			makeafile_iddotdiz(theApp.m_datZipList[zipPosPtr].filename, tmpFolder);
			files.setTimestamp(tmpFolder+"\\"+tempZIPdata.ROMsMap[i].name, tempZIPdata.ROMsMap[i].date);
			tempZIPdata.ROMsMap[i].status = 1;
		}
	}

	// 7) all files present?  no, clean up and abort.
	for (int i=0; i< numRoms; i++) //-outer loop= # of ROMS from the dat we're looking for.
	{
		if (tempZIPdata.ROMsMap[i].status != 1)	// if we've already found this ROM, skipit
			return false;
	}


	// 8) rezip with maximum compression
	// create a new filename
	zipfilename = extractFilenameWOPath(zipName);
	zipfilename.Insert(0,"WIP");

	m_zip.OpenZip(m_SourcePath+"\\"+zipfilename, theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"); // create a fresh zip file

	for (int i=0; i< numRoms; i++)
	{
		romfilename = tempZIPdata.ROMsMap[i].name;
		m_zip.AddFileToZip(theApp.m_tmpWorkingFolder+"\\DOSCenterUz\\"+romfilename);
	}
	m_zip.CloseZip();

	//9) move file back to source folder, delete old file (or rename it to be safe)
	remove(m_SourcePath+zipName);
	MoveFile(m_SourcePath+"\\"+zipfilename, m_SourcePath+zipName);
	
	
	return true;
}
// scan for a rom inside of n number of update pack files
bool CDOSCenterDlg::getROMFromUpdatePacks(CString targetFilename, CString tmpFolder, unsigned int CRC, unsigned int timestamp)
{
	bool status=true;


	return status;
}

bool CDOSCenterDlg::unzipAndFixAROMFromAZip(CString sourceZipname, CString targetFilename, CString tmpFolder, unsigned int CRC, unsigned int timestamp)
{
	UZ_FileInfo info;	
	bool status;	
	CFileStuff files;
	// is the requested file a folder?
	if (targetFilename.Right(1) ==("\\")) 
	{
		CString newFolder = (targetFilename.Left(targetFilename.ReverseFind('\\')));
		CreateDirectory(_T(tmpFolder+"\\"+newFolder), NULL);
		return (files.setTimestampFolder(tmpFolder+"\\"+newFolder, timestamp));
	}
	// is the requested file in a folder, and have we created the target folder yet?
	if (targetFilename.Find("\\") != -1)
	{
		CString folder = targetFilename.Left(targetFilename.Find("\\")+1);
		unzipAndFixAROMFromAZip(sourceZipname, folder, tmpFolder, CRC, timestamp);	// this should just create the folder and return here immediately.
	}


	m_uz.OpenZip(sourceZipname);
	// return on error

	m_uz.GotoFirstFile();

	do // inner loop - number of roms available in this zip
	{
		m_uz.GetFileInfo(info);	// get filename info out of zip

		if (CRC == info.dwCRC)	// CRC match!  unzip it to temp folder.  
		{
			if (info.bFolder) continue; // only extract files here.
			
			if (!m_uz.UnzipFile(tmpFolder, 1))	// extract without any file path
			{	
				AfxMessageBox("Ack.  An unzip error occurred. This zip file might be old and compressed with Shrink based compression. \
				\r\nYou should try to refresh/recompress this zip file with winRAR or similar and try again." , MB_ICONERROR, 0);
				status = false;
				goto exit;
			}	
			CString filenameNopath = extractFilenameWOPath(info.szFileName);
			// rename the file
			if (!MoveFile(tmpFolder+"\\"+filenameNopath, tmpFolder+"\\"+targetFilename))
			{
				AfxMessageBox("Error renaming file! "+tmpFolder+"\\"+info.szFileName, MB_ICONEXCLAMATION, 0);
				status = false;
				goto exit;
			}
			else	// file extracted and renamed.  No need to look further.
			{
				files.setTimestamp(tmpFolder+"\\"+targetFilename, timestamp);
				status=true;
				goto exit;
			}
		}
	}while (m_uz.GotoNextFile());
	
	status = false;	// not found
exit:
	m_uz.CloseZip();
	return status;
}



bool CDOSCenterDlg::makeafile_iddotdiz(CString filename, CString tmpFolder)
{
	FILE* outFile;
	CString diz;
	CdizInfo fiz;	// file_id.diz structure class
	CString name, flags, version, year, publisher, genre, dizname, language;
	extern dizInfo	m_dizInfo;

	if (filename.Find('\\') != -1) 
		filename = filename.Right(filename.GetLength() - (filename.ReverseFind('\\')) -1 );

	filename.Trim("\\");
	flags = "Flags:";
	language = "Language/Country:";
	version = "Version:";
	year = "Year:";
	publisher = "Publisher:";
	genre = "Genre(s):";
	name = "Name:";

	fiz.zipName2Vars(filename, false);	// populate local variables with data based off filename

	diz = m_dizInfo.filename+"\r\n";
	diz+= name+m_dizInfo.name+"\r\n";
	diz+= version+m_dizInfo.version+"\r\n";
	diz+= language+m_dizInfo.languageTxt+"\r\n";
	diz+= flags+m_dizInfo.flagsTxt+"\r\n";
	diz+= year+m_dizInfo.year+"\r\n";
	diz+=publisher+m_dizInfo.publisher+"\r\n";
	diz+=genre+m_dizInfo.genre+"\r\n";

	// create the file_id.diz	
	outFile = fopen(tmpFolder+"\\file_id.diz","wb");
	if ( outFile != NULL )
		fwrite(diz, sizeof( char ), diz.GetLength(), outFile );
		
	if ( outFile != NULL )
	{
		fclose(outFile);
		outFile=NULL;
	}
	return true;
}

// compare a .dat entry against files in a given zip
// update the status of each as we find them
void CDOSCenterDlg::checkDatvsZip(int datPos, int m_nFileCount, bool cleanup)
{
	m_zipCRCmatches=0;
	m_zipNameMatches=0;
	m_zipTimestampMatches=0;
	m_exactMatches=0;
	CString romfilename, datfilename;

	// first, eliminate exact matches.  (CRC+filename are identical in both the .dat and the zip)
	// update the status on each.  sadly we have to spin through every single rom in the dat against every single rom in the zip
	// we allow FILENAME, filename, path\filename to all be perfect matches because we're nice.
	// in the future, a perfect match will only mean filename+crc+timestamp
	// we even check ignored files at this level since ignored files can help us identify the exact .dat entry match
	for (int i=0; i<m_nFileCount; i++)
	{
		romfilename = theApp.m_tmpzipList[i].fileName;
		for (int j=0; j<theApp.m_datZipList[datPos].fileCount; j++)
			if (theApp.m_datZipList[datPos].ROMsMap[j].status ==0)	// if already checked the .dat rom, skipit
			{
				datfilename = theApp.m_datZipList[datPos].ROMsMap[j].name;
				if (theApp.m_tmpzipList[i].crc == theApp.m_datZipList[datPos].ROMsMap[j].crc)	// crc match?
				{
					if (theApp.m_tmpzipList[i].fileName == theApp.m_datZipList[datPos].ROMsMap[j].name) // name match too?
					{
						//if (theApp.m_tmpzipList[i].date == theApp.m_datZipList[datPos].ROMsMap[j].date) // timestamp match!? - future work
						{
							m_exactMatches++;
							theApp.m_tmpzipList[i].status = STATUS_ROM_PERFECT_MATCH;
							theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_PERFECT_MATCH;
							break;
						} // timestamp match
					} //name match
					else	// may be a case issue.  
					if (romfilename.MakeLower() == datfilename.MakeLower())
					{
						m_exactMatches++;
						theApp.m_tmpzipList[i].status = STATUS_ROM_PERFECT_MATCH;	//todo - set to STATUS_ROM_NAMEWEIRD
						theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_PERFECT_MATCH;
						break;
					} 
					else	// may be a buried zip
					{
						if (!m_buriedZipFolder.IsEmpty())
						{
							romfilename.Replace(m_buriedZipFolder.MakeLower(),"");
							if (romfilename == datfilename)
							{
								m_exactMatches++;
								theApp.m_tmpzipList[i].status = STATUS_ROM_PERFECT_MATCH;	//todo - set to STATUS_ROM_NAMEWEIRD
								theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_PERFECT_MATCH;
							}
						}
					}
				} // crc match
			} // dat things we have not already checked
	}
	
	// 2nd pass through the dat+zip
	// now look for CRC matches but filename mismatches. (ie, game.exe has been renamed to play.exe, but the contents are the same)
	// we don't do this as part of the above check because we can run into a situation where there are 2 files with the same CRC (different name) and as we're scanning
	// we would end up marking off a CRC match+filename mismatch, but if we'd scanned a bit more, we'd catch a perfect match.
	for (int i=0; i<m_nFileCount; i++) // ..for each rom
	{
		if ((theApp.m_tmpzipList[i].status & STATUS_ROM_PERFECT_MATCH) == STATUS_ROM_PERFECT_MATCH)	// if already zip rom found above, skipit
			continue;
		else
		for (int j=0; j<theApp.m_datZipList[datPos].fileCount; j++) // ..and for each dat entry
		{
			if ((theApp.m_datZipList[datPos].ROMsMap[j].status & STATUS_ROM_PERFECT_MATCH) == STATUS_ROM_PERFECT_MATCH)	// if already checked the .dat rom, skipit
				continue;
			else
			if (theApp.m_tmpzipList[i].crc == theApp.m_datZipList[datPos].ROMsMap[j].crc)	// CRC match? yay!
			{	
				//if (theApp.m_tmpzipList[i].date == theApp.m_datZipList[datPos].ROMsMap[j].date) // timestamp match!? - future work
				m_zipCRCmatches++;
				theApp.m_tmpzipList[i].status = STATUS_ROM_CRC_MATCH;
				theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_CRC_MATCH;
				theApp.m_tmpzipList[i].newFileName = theApp.m_datZipList[datPos].ROMsMap[j].name;	// save the name it should be
				continue;
			}
		}
	}

	// 3rd pass
	// now look for filename matches but CRC mismatches (.exe file has been hacked and no longer matches what the .dat file says)
	// or the filename is in the ignore list.
	for (int i=0; i<m_nFileCount; i++) // ..for each rom in the zip...
	{
		CString romfilename = theApp.m_tmpzipList[i].fileName;
		if ((theApp.m_tmpzipList[i].status & STATUS_ROM_CRC_MATCH) == STATUS_ROM_CRC_MATCH)	// if zip rom already found anywhere above, skipit
			continue;
		// file in ignore list?
		CString tmpfilename = romfilename; 
		CString ext = extractExtension(tmpfilename);
		if (skipafile(tmpfilename, ext, theApp.m_tmpzipList[i].crc, theApp.m_tmpzipList[i].size))
		{
			m_zipIgnored++;	
			theApp.m_tmpzipList[i].status = STATUS_ROM_IGNORED;
			continue;
		}		

		for (int j=0; j<theApp.m_datZipList[datPos].fileCount; j++) // ..and for each dat entry
		{
			CString datfilename = theApp.m_datZipList[datPos].ROMsMap[j].name;
			if ((theApp.m_datZipList[datPos].ROMsMap[j].status & STATUS_ROM_CRC_MATCH) != STATUS_ROM_CRC_MATCH)	// if already checked the .dat rom, skipit
			{				
				if (theApp.m_tmpzipList[i].fileName == theApp.m_datZipList[datPos].ROMsMap[j].name)	// filename match? yay!
				{
					m_zipNameMatches++;
					theApp.m_tmpzipList[i].status = STATUS_ROM_FILENAME_MATCH;
					theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_FILENAME_MATCH;
				//	if (theApp.m_tmpzipList[i].status = STATUS_ROM_IGNORED)	// was this file ignored already?
				//		theApp.m_datZipList[datPos].ROMsMap[j].status |= STATUS_ROM_IGNORED;
					continue;
				}
				else // may be a case issue
				if (romfilename.MakeLower() == datfilename.MakeLower())
				{
					m_zipNameMatches++;
					theApp.m_tmpzipList[i].status = STATUS_ROM_FILENAME_MATCH;
					theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_FILENAME_MATCH;
				//	if (theApp.m_tmpzipList[i].status = STATUS_ROM_IGNORED)	// was this file ignored already?
				//		theApp.m_datZipList[datPos].ROMsMap[j].status |= STATUS_ROM_IGNORED;
					continue;
				}	
				else	// may be buried
				if (!m_buriedZipFolder.IsEmpty())
				{
					romfilename.Replace(m_buriedZipFolder.MakeLower(),"");
					if (romfilename == datfilename)
					{
						m_zipNameMatches++;
						theApp.m_tmpzipList[i].status = STATUS_ROM_FILENAME_MATCH;
						theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_FILENAME_MATCH;
					//	if (theApp.m_tmpzipList[i].status = STATUS_ROM_IGNORED)	// was this file ignored already?
					//		theApp.m_datZipList[datPos].ROMsMap[j].status |= STATUS_ROM_IGNORED;
						continue;
					}
				}
			} // unchecked dat entries
		} // each dat entry
	} // each zip entry

	// Finally see if there is anything in the zip file that is on the ignore list.
	// we've actually already CRC+filename matched everything anyway, so if something in the ignore list matched, it'll already be counted.
	// this all is assuming the .dat file is more perfect than the zip file we're scanning, but that's kinda the point.
/*	for (int i=0; i<m_nFileCount; i++) // ..for each rom
	{
		if ((theApp.m_tmpzipList[i].status & STATUS_ROM_FILENAME_MATCH) == STATUS_ROM_FILENAME_MATCH)	// if already found, skipit
			continue;
		CString tmpfilename = theApp.m_tmpzipList[i].fileName;
		CString ext = extractExtension(tmpfilename);
		if (skipafile(tmpfilename, ext, theApp.m_tmpzipList[i].crc, theApp.m_tmpzipList[i].size))
		{
			m_exactMatches++;	
			theApp.m_tmpzipList[i].status = STATUS_ROM_IGNORED;
			//theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_CRC_MATCH+STATUS_ROM_FILENAME_MATCH+STATUS_ROM_TIMESTAMP_MATCH;
		}
	}
*/
	// and check if there is anything in the .dat file that we didn't find in the zip that is on our ignore list. (like file_id.diz)
	for (int j=0; j<theApp.m_datZipList[datPos].fileCount; j++) // ..and for each dat entry
	{
		if (theApp.m_datZipList[datPos].ROMsMap[j].status != 0) 
			continue;
		
		CString tmpfilename = theApp.m_datZipList[datPos].ROMsMap[j].name;
		CString ext = extractExtension(tmpfilename);
		if (skipafile(tmpfilename, ext, theApp.m_datZipList[datPos].ROMsMap[j].crc, theApp.m_datZipList[datPos].ROMsMap[j].size))
		{
			m_datIgnored++;	
			//theApp.m_tmpzipList[i].status = STATUS_ROM_IGNORED;
			theApp.m_datZipList[datPos].ROMsMap[j].status = STATUS_ROM_IGNORED;
		}
	}

	if (cleanup)
	{
	// cleanup the .dat map so we can scan it again
	for (int j=0; j<theApp.m_datZipList[datPos].fileCount; j++) // ..and for each dat entry
		theApp.m_datZipList[datPos].ROMsMap[j].status = 0;
	}
}
// returns the index in the .dat file that matches the supplied filename
int CDOSCenterDlg::getDatPtr(CString filename)
{
	int ptr=0;
	theApp.m_datZipListit = theApp.m_datZipList.begin();
	while (theApp.m_datZipListit != theApp.m_datZipList.end())
	{
		if (filename == theApp.m_datZipListit->second.filename)
			goto exit;
		theApp.m_datZipListit++;
		ptr++;
	}
	ptr=-1;
exit:
	return ptr;
}
